@@ -1,11 +1,11 @@
 ;;; ess-eldoc.el --- Use eldoc to report R function names.
 
 ;; Copyright (C) 1997--2009 A.J. Rossini, Rich M. Heiberger, Martin
-;;	Maechler, Kurt Hornik, Rodney Sparapani, and Stephen Eglen.
+;;      Maechler, Kurt Hornik, Rodney Sparapani, and Stephen Eglen.
 
-;; Original Author: Stephen Eglen
+;; Author: Stephen Eglen
 ;; Created: 2007-06-30
-;; Maintainers: ESS-core <ESS-core@r-project.org>
+;; Maintainer: ESS-core <ESS-core@r-project.org>
 
 ;; This file is part of ESS
 
@@ -25,6 +25,10 @@
 
 ;;; Commentary:
 
+;;;;; eldoc funcitonality has been moved into the core ;;;;;
+;;;;; this file has no effect and is left in ESS in order not to break
+;;;;; users configuration
+
 ;; This is an initial attempt to use the emacs facility ELDOC in R
 ;; buffers.  Eldoc is used in Emacs lisp buffers to show the function
 ;; arglist and docstrings for variables.  To try it, view an emacs
@@ -82,6 +86,8 @@
 ;; Emacs 21, because it needs the variable
 ;; eldoc-documentation-function.
 
+;;;; VS [25-02-2012]: all these issues were at least partially addresed in the
+;;;; new implementation:
 
 ;; Bug (in eldoc?): the arg list for legend() is too long to fit in
 ;; minibuffer, and it seems that we see the last N lines of the arg
@@ -103,96 +109,69 @@
 
 ;;; Code:
 
-;; This could be done on buffer local basis.
-(setq ess-r-args-noargsmsg "")
+;; ;; This could be done on buffer local basis.
+;; (setq ess-r-args-noargsmsg "")
 
-;; following two defvars are not currently used.
-(defvar ess-eldoc-last-name nil
-  "Name of the last function looked up in eldoc.
-We remember this to see whether we need to look up documentation, or used
-the cached value in `ess-eldoc-last-args'.")
+;; ;; following two defvars are not currently used.
+;; (defvar ess-eldoc-last-name nil
+;;   "Name of the last function looked up in eldoc.
+;; We remember this to see whether we need to look up documentation, or used
+;; the cached value in `ess-eldoc-last-args'.")
 
-(defvar ess-eldoc-last-args nil
-  "Args list last looked up for eldoc.  Used as cache.")
+;;  (defvar ess-eldoc-last-args nil
+;;   "Args list last looked up for eldoc.  Used as cache.")
 
-(defun ess-eldoc ()
-  "Return the doc string, or nil.
-If an ESS process is not associated with the buffer, do not try
-to look up any doc strings."
-  (interactive)
-  (let ((doc nil)
-	name)
-    (when ess-local-process-name
-      (setq name (ess-guess-fun))		;guess the word at point.
-      (unless (= (length name) 0)
-	;; look up function name at point.
-	(setq doc (ess-r-args-get name)))
-      (unless doc
-	;; no function found at point; see if we are in a arg-list
-	;; of a function.
-	(save-excursion
-	  (condition-case nil
-	      (progn
-		(up-list -1)
-		(setq name (ess-guess-fun))
-		(setq doc (ess-r-args-get name)))
-	    ;; error handler -- not possible to go up one list level.
-	    (error nil) ))))
-    (if doc
-	(concat name ": " doc)
-      doc)))
+;; (defun ess-eldoc-2 ()
+;;   ;; simple, old version.
+;;   (interactive)
+;;   (ess-r-args-get (ess-read-object-name-default)))
 
-(defun ess-eldoc-2 ()
-  ;; simple, old version.
-  (interactive)
-  (ess-r-args-get (ess-read-object-name-default)))
+;; (defun ess-eldoc-1 ()
+;;   "Return the doc string, or nil.
+;; This is the first version; works only on function name, not within arg list."
+;;   (interactive)
 
-(defun ess-eldoc-1 ()
-  "Return the doc string, or nil.
-This is the first version; works only on function name, not within arg list."
-  (interactive)
+;;   ;; Possible ways to get the function at point.
+;;   ;;(setq name (thing-at-point 'sexp))
+;;   ;;(setq name (ess-read-object-name-default))
+;;   ;;(setq name (find-tag-default))
 
-  ;; Possible ways to get the function at point.
-  ;;(setq name (thing-at-point 'sexp))
-  ;;(setq name (ess-read-object-name-default))
-  ;;(setq name (find-tag-default))
-
-  (if ess-current-process-name
-      (progn
-	(setq name (ess-guess-fun))		;guess the word at point.
-	(if (equal (length name) 0)
-	    nil
-	  ;; else
-	  (unless (equal name ess-eldoc-last-name)
-	    ;; name is different to the last name we lookedup, so get
-	    ;; new args from R and store them.
-	    (setq ess-eldoc-last-args (ess-r-args-get name)
-		  ess-eldoc-last-name name))
-	  ess-eldoc-last-args))
-    ;; no ESS process current.
-    nil)
-)
+;;   (if ess-current-process-name
+;;       (progn
+;;      (setq name (ess-guess-fun))             ;guess the word at point.
+;;      (if (equal (length name) 0)
+;;          nil
+;;        ;; else
+;;        (unless (equal name ess-eldoc-last-name)
+;;          ;; name is different to the last name we lookedup, so get
+;;          ;; new args from R and store them.
+;;          (setq ess-eldoc-last-args (ess-r-args-get name)
+;;                ess-eldoc-last-name name))
+;;        ess-eldoc-last-args))
+;;     ;; no ESS process current.
+;;     nil)
+;; )
 
 
-(defsubst ess-guess-fun ()
-  "Guess what the function at point is."
-  ;; Derived from Man-default-man-entry in man.el
-  (let (word)
-    (save-excursion
-      (skip-chars-backward "-a-zA-Z0-9._+:")
-      (let ((start (point)))
-	(skip-chars-forward "-a-zA-Z0-9._+:")
-	(setq word (buffer-substring-no-properties start (point)))))
-      word))
+;; (defsubst ess-guess-fun ()
+;;   "Guess what the function at point is."
+;;   ;; Derived from Man-default-man-entry in man.el
+;;   (let (word)
+;;     (save-excursion
+;;       (skip-chars-backward "-a-zA-Z0-9._+:")
+;;       (let ((start (point)))
+;;      (skip-chars-forward "-a-zA-Z0-9._+:")
+;;      (setq word (buffer-substring-no-properties start (point)))))
+;;       word))
 
 (defun ess-use-eldoc ()
-  "Switch on eldoc for ESS (R mode only)."
-  (interactive)
-  (set (make-local-variable 'eldoc-documentation-function) 'ess-eldoc)
-  (eldoc-mode t))
+  "Does nothing. Defined not to break old users' code."
+  (interactive))
 
 ;; For now, while testing, switch on ess-eldoc.  Later, ths could be removed
 ;; and instead ask user to add it.
-(add-hook 'R-mode-hook 'ess-use-eldoc)
+;; (add-hook 'R-mode-hook 'ess-use-eldoc)
 
 (provide 'ess-eldoc)
+
+;;; ess-eldoc.el ends here
