@@ -1,11 +1,11 @@
 ;; ess-rd.el --- Support for editing R documentation (Rd) source
 
 ;; Copyright (C) 1997--2005  A.J. Rossini, Rich M. Heiberger, Martin
-;;	Maechler, Kurt Hornik, Rodney Sparapani, and Stephen Eglen.
+;;      Maechler, Kurt Hornik, Rodney Sparapani, and Stephen Eglen.
 
-;; Original Author: KH <Kurt.Hornik@ci.tuwien.ac.at>
+;; Author: KH <Kurt.Hornik@ci.tuwien.ac.at>
 ;; Created: 25 July 1997
-;; Maintainers: ESS-core <ESS-core@stat.math.ethz.ch>
+;; Maintainer: ESS-core <ESS-core@r-project.org>
 
 ;; This file is part of ESS (Emacs Speaks Statistics).
 
@@ -33,10 +33,10 @@
   "Current version of ess-rd.el.")
 
 (defvar essddr-maintainer-address
-  "ESS Core Team <ess-core@stat.math.ethz.ch>"
+  "ESS Core Team <ess-core@r-project.org>"
   "Current maintainer of ess-rd.el.")
 
-(defun Rd-active-mark () nil)		;silence compiler.
+(defun Rd-active-mark () nil)           ;silence compiler.
 (if (featurep 'xemacs)
     ;; Special support for XEmacs (curtesy of auctex):
     (defun Rd-active-mark ()
@@ -45,17 +45,16 @@
   ;; else:  special support for GNU Emacs
   (defun Rd-active-mark ()
     (and transient-mark-mode mark-active))
-)
+  )
 
+(autoload 'ess-eval-region              "ess-inf" "[autoload]" t)
+(autoload 'ess-eval-line-and-step       "ess-inf" "[autoload]" t)
+(autoload 'ess-switch-process           "ess-inf" "[autoload]" t)
+(autoload 'ess-switch-to-ESS            "ess-inf" "[autoload]" t)
+(autoload 'ess-switch-to-end-of-ESS     "ess-inf" "[autoload]" t)
 
-(autoload 'ess-eval-region		"ess-inf" "[autoload]" t)
-(autoload 'ess-eval-line-and-step	"ess-inf" "[autoload]" t)
-(autoload 'ess-switch-process		"ess-inf" "[autoload]" t)
-(autoload 'ess-switch-to-ESS		"ess-inf" "[autoload]" t)
-(autoload 'ess-switch-to-end-of-ESS	"ess-inf" "[autoload]" t)
-
-(autoload 'ess-help-mode		"ess-help" "[autoload]" t)
-(autoload 'ess-nuke-help-bs		"ess-help" "[autoload]" t)
+(autoload 'ess-help-mode                "ess-help" "[autoload]" t)
+(autoload 'ess-nuke-help-bs             "ess-help" "[autoload]" t)
 
 (defvar Rd-mode-abbrev-table nil
   "Abbrev table for R documentation keywords.
@@ -121,7 +120,7 @@ All Rd mode abbrevs start with a grave accent (`).")
 (if Rd-mode-parse-syntax-table
     ()
   (setq Rd-mode-parse-syntax-table
-	(copy-syntax-table Rd-mode-syntax-table))
+        (copy-syntax-table Rd-mode-syntax-table))
   ;; To make parse-partial-sexps do the thing we want for computing
   ;; indentations
   (modify-syntax-entry ?\( "_" Rd-mode-parse-syntax-table)
@@ -140,12 +139,13 @@ All Rd mode abbrevs start with a grave accent (`).")
 (defvar Rd-keywords
   '(
     ;; the next two lines: only valid in R <= 2.8.1
-    "Alpha" "Gamma" "alpha" "beta" "epsilon" "lambda" "mu" "pi" "sigma"
-    "ge" "le" "left" "right"
+    ;; commented out on 2011-01-14 for ESS version 5.13:
+    ;; "Alpha" "Gamma" "alpha" "beta" "epsilon" "lambda" "mu" "pi" "sigma"
+    ;; "ge" "le" "left" "right"
     ;;
     "R" "RdOpts" "S3method" "S4method" "Sexpr" "acronym"
     "bold" "cite" "code" "command" "cr" "dQuote" "deqn" "dfn" "dontrun"
-    "dontshow" "dots" "email" "emph" "enc" "env" "eqn" "file"
+    "dontshow" "donttest" "dots" "email" "emph" "enc" "env" "eqn" "figure" "file"
     "href" "if" "ifelse"
     "item" "kbd" "ldots" "linkS4class" "link" "method"
     "newcommand" "option" "out"
@@ -156,25 +156,25 @@ All Rd mode abbrevs start with a grave accent (`).")
 ;; Need to fix Rd-bold-face problem.
 ;;
 ;; (defvar Rd-bold-face 'bold)
-;(defvar Rd-bold-face nil)
-;(make-face Rd-bold-face "R documentation bold face")
-;(make-face-bold Rd-bold-face
+                                        ;(defvar Rd-bold-face nil)
+                                        ;(make-face Rd-bold-face "R documentation bold face")
+                                        ;(make-face-bold Rd-bold-face
 
 (defvar Rd-font-lock-keywords
   (list
    (cons
     (concat "\\\\\\("
-	    (mapconcat 'identity Rd-section-names "\\|")
-	    "\\>\\)")
+            (mapconcat 'identity Rd-section-names "\\|")
+            "\\>\\)")
     'font-lock-reference-face) ; Rd-bold-face
    (cons
     (concat "\\\\\\("
-	    (mapconcat 'identity Rd-keywords "\\|")
-	    "\\>\\)")
+            (mapconcat 'identity Rd-keywords "\\|")
+            "\\>\\)")
     'font-lock-keyword-face)
    '("^#\\(ifn?def\\)\\s-+\\(\\sw+\\)"
-    (1 font-lock-builtin-face)
-    (2 font-lock-variable-name-face nil t))
+     (1 font-lock-builtin-face)
+     (2 font-lock-variable-name-face nil t))
    '("^#\\(endif\\)" 1 font-lock-builtin-face))
   "Additional Rd expressions to highlight.")
 
@@ -209,25 +209,25 @@ All Rd mode abbrevs start with a grave accent (`).")
 
 (defvar Rd-mode-menu
   (list "Rd"
-	["Markup [word]"		Rd-font t]
-	["Insert Item"			Rd-mode-insert-item t]
-	["Insert Section"		Rd-mode-insert-section t]
-	["Insert Skeleton"		Rd-mode-insert-skeleton t]
-	"-"
-	["Preview"			Rd-preview-help t]
-	"-"
-	["Eval Line"			ess-eval-line-and-step t]
-	["Eval Region"			ess-eval-region t]
-	["Switch to ESS Process"	ess-switch-to-ESS t]
-	["Switch the ESS Process"	ess-switch-process t]
-	["Switch to end{ESS Pr}"	ess-switch-to-end-of-ESS t]
-	"-"
-	["Toggle Abbrev Mode"		abbrev-mode t]
-	["Toggle Auto-Fill Mode"	auto-fill-mode t]
-	"-"
-	["Submit Bug Report"		Rd-submit-bug-report t]
-	"-"
-	["Describe Rd Mode"		Rd-describe-major-mode t])
+        ["Markup [word]"                Rd-font t]
+        ["Insert Item"                  Rd-mode-insert-item t]
+        ["Insert Section"               Rd-mode-insert-section t]
+        ["Insert Skeleton"              Rd-mode-insert-skeleton t]
+        "-"
+        ["Preview"                      Rd-preview-help t]
+        "-"
+        ["Eval Line"                    ess-eval-line-and-step t]
+        ["Eval Region"                  ess-eval-region t]
+        ["Switch to ESS Process"        ess-switch-to-ESS t]
+        ["Switch the ESS Process"       ess-switch-process t]
+        ["Switch to end{ESS Pr}"        ess-switch-to-end-of-ESS t]
+        "-"
+        ["Toggle Abbrev Mode"           abbrev-mode t]
+        ["Toggle Auto-Fill Mode"        auto-fill-mode t]
+        "-"
+        ["Submit Bug Report"            Rd-submit-bug-report t]
+        "-"
+        ["Describe Rd Mode"             Rd-describe-major-mode t])
   "Menu used in Rd mode.")
 
 (defvar Rd-mode-hook nil
@@ -238,14 +238,14 @@ All Rd mode abbrevs start with a grave accent (`).")
 
 
 (defvar Rd-font-list
-  '((?\C-b "\\bold{"	"}")
-    (?\C-c "\\code{"	"}")
-    (?\C-e "\\emph{"	"}")
-    (?\C-l "\\link{"	"}")
+  '((?\C-b "\\bold{"    "}")
+    (?\C-c "\\code{"    "}")
+    (?\C-e "\\emph{"    "}")
+    (?\C-l "\\link{"    "}")
     (?l "\\code{\\link{" "}}")
-    (?\C-m "\\email{"	"}")
-    (?\C-q "\\eqn{"	"}")
-    (?\C-u "\\url{"	"}")
+    (?\C-m "\\email{"   "}")
+    (?\C-q "\\eqn{"     "}")
+    (?\C-u "\\url{"     "}")
     )
   "List of ``fonts'' used by Rd-font.
 
@@ -253,7 +253,7 @@ Each entry is a list.
 The first element is the key to activate the font.
 The second element is the string to insert before point, and the third
 element is the string to insert after point."
-)
+  )
 
 
 ;;;###autoload
@@ -285,8 +285,8 @@ To automatically turn on the abbrev(iate) features, add the
 following lines to your `.emacs' file:
 
   (add-hook 'Rd-mode-hook
-	    (lambda ()
-	      (abbrev-mode 1)))
+            (lambda ()
+              (abbrev-mode 1)))
 "
 
   (interactive)
@@ -309,11 +309,12 @@ following lines to your `.emacs' file:
 
   (require 'easymenu)
   (easy-menu-define Rd-mode-menu-map Rd-mode-map
-		    "Menu keymap for Rd mode." Rd-mode-menu)
+    "Menu keymap for Rd mode." Rd-mode-menu)
   (easy-menu-add Rd-mode-menu-map Rd-mode-map)
 
   (turn-on-auto-fill)
   (message "Rd mode version %s" essddr-version)
+  (setq ess-language "S" ess-dialect  "R"); (buffer local)
   (run-hooks 'Rd-mode-hook))
 
 ;; FIXME: The following should be moved to ess-utils.el, no? (MM thinks)
@@ -338,14 +339,14 @@ following lines to your `.emacs' file:
   (let ((pos (point)))
     (save-excursion
       (if (and (re-search-backward
-		"\\\\\\(usage\\|examples\\|synopsis\\)" nil t)
-	       (re-search-forward "\\s(" nil t))
-	  (condition-case ()
-	      (progn
-		(up-list 1)
-		(< pos (point)))
-	    (error t))
-	nil))))
+                "\\\\\\(usage\\|examples\\|synopsis\\)" nil t)
+               (re-search-forward "\\s(" nil t))
+          (condition-case ()
+              (progn
+                (up-list 1)
+                (< pos (point)))
+            (error t))
+        nil))))
 
 (defun Rd-mode-in-preprocessor-line-p ()
   (save-excursion
@@ -366,34 +367,34 @@ following lines to your `.emacs' file:
       0)
      (t
       (let ((p (progn
-		 (re-search-forward "[ \t]*\\s)*" (ess-point 'eol) t)
-		 (point))))
-	(if (or (< (forward-line -1) 0)
-		(Rd-mode-in-verbatim-p))
-	    0
-	  (set-syntax-table Rd-mode-parse-syntax-table)
-	  (while (and (or (looking-at "[ \t]*$")
-			  (Rd-mode-in-preprocessor-line-p))
-		      (not (bobp)))
-	    (forward-line -1))
-	  (re-search-forward "[ \t]*\\s)*" (ess-point 'eol) t)
-	  (prog1
-	      (+ (current-indentation)
-		 (* (car (parse-partial-sexp (point) p))
-		    Rd-indent-level))
-	    (set-syntax-table Rd-mode-syntax-table))))))))
+                 (re-search-forward "[ \t]*\\s)*" (ess-point 'eol) t)
+                 (point))))
+        (if (or (< (forward-line -1) 0)
+                (Rd-mode-in-verbatim-p))
+            0
+          (set-syntax-table Rd-mode-parse-syntax-table)
+          (while (and (or (looking-at "[ \t]*$")
+                          (Rd-mode-in-preprocessor-line-p))
+                      (not (bobp)))
+            (forward-line -1))
+          (re-search-forward "[ \t]*\\s)*" (ess-point 'eol) t)
+          (prog1
+              (+ (current-indentation)
+                 (* (car (parse-partial-sexp (point) p))
+                    Rd-indent-level))
+            (set-syntax-table Rd-mode-syntax-table))))))))
 
 (defun Rd-mode-indent-line ()
   "Indent current line as Rd source."
   (interactive)
   (let ((ic (Rd-mode-calculate-indent))
-	(rp (- (current-column) (current-indentation))))
-    (if ic				; Not inside a verbatim
-	(if (< ic 0)
-	    (error "Unmatched parenthesis")
-	  (indent-line-to ic)
-	  (if (> rp 0)
-	      (move-to-column (+ ic rp)))))))
+        (rp (- (current-column) (current-indentation))))
+    (if ic                              ; Not inside a verbatim
+        (if (< ic 0)
+            (error "Unmatched parenthesis")
+          (indent-line-to ic)
+          (if (> rp 0)
+              (move-to-column (+ ic rp)))))))
 
 (defun Rd-mode-insert-item ()
   (interactive)
@@ -403,12 +404,12 @@ following lines to your `.emacs' file:
 
 (defun Rd-mode-insert-section ()
   (interactive)
-  (let ((s (completing-read
-	    "Insert section: "
-	    (mapcar '(lambda (x) (cons x x)) Rd-section-names)
-	    nil t)))
+  (let ((s (ess-completing-read
+            "Insert section: "
+            (mapcar (lambda (x) (cons x x)) Rd-section-names)
+            nil t)))
     (if (string= s "")
-	(progn (insert "\\section{}{") (backward-char 2))
+        (progn (insert "\\section{}{") (backward-char 2))
       (insert (format "\\%s{" s)))))
 
 (defun Rd-mode-insert-skeleton ()
@@ -438,54 +439,68 @@ following lines to your `.emacs' file:
   (interactive "c")
   ;;TeX had : (Rd-update-style)
   (let* ((entry (assoc what Rd-font-list))
-	 (before (nth 1 entry))
-	 (after (nth 2 entry)))
+         (before (nth 1 entry))
+         (after (nth 2 entry)))
     (cond ((null entry) ;; help on possibilities :
-	   (let ((help
-		  (concat
-		   "Rd Markup (available from C-c C-f):\n\n\t"
-		   "KEY          Rd-Markup\n\n"
-		   (mapconcat
-		    '(lambda (entry)
-		       ;; A textual description of an ENTRY in TeX-font-list.
-		       (concat (format "%11s  "
-				       (key-description
-					(char-to-string (nth 0 entry))))
-			       (format "%14s %-3s"
-				       (nth 1 entry) (nth 2 entry))))
-		    Rd-font-list "\n"))))
-	     (with-output-to-temp-buffer "*Help*"
-	       (set-buffer "*Help*")
-	       (insert help))))
-
-	  ((Rd-active-mark)
-	   (save-excursion
-	     (cond ((> (mark) (point))
-		    (insert before)
-		    (goto-char (mark))
-		    (insert after))
-		   (t
-		    (insert after)
-		    (goto-char (mark))
-		    (insert before)))))
-	  (t
-	   (insert before)
-	   (save-excursion
-	     (insert after))))))
+           (let ((help
+                  (concat
+                   "Rd Markup (available from C-c C-f):\n\n\t"
+                   "KEY          Rd-Markup\n\n"
+                   (mapconcat
+                    (lambda (entry)
+                      ;; A textual description of an ENTRY in TeX-font-list.
+                      (concat (format "%11s  "
+                                      (key-description
+                                       (char-to-string (nth 0 entry))))
+                              (format "%14s %-3s"
+                                      (nth 1 entry) (nth 2 entry))))
+                    Rd-font-list "\n"))))
+             (with-output-to-temp-buffer "*Help*"
+               (set-buffer "*Help*")
+               (insert help))))
 
+          ((Rd-active-mark)
+           (save-excursion
+             (cond ((> (mark) (point))
+                    (insert before)
+                    (goto-char (mark))
+                    (insert after))
+                   (t
+                    (insert after)
+                    (goto-char (mark))
+                    (insert before)))))
+          (t
+           (insert before)
+           (save-excursion
+             (insert after))))))
 
 (defun Rd-preview-help ()
+  "Preview the current buffer contents using `Rd-to-help-command'.
+If the current buffer is not associated with a file, create a
+temporary one in `temporary-file-directory'.
+"
   (interactive)
   (require 'ess-help)
-  (let ((sbuf buffer-file-name)
-	(pbuf (get-buffer-create "R Help Preview")))
+  (let ((file  buffer-file-name)
+        (pbuf (get-buffer-create "R Help Preview"))
+        del-p shcmd)
+    (unless file
+      (setq file  (make-temp-file "RD_" nil ".Rd"))
+      (write-region (point-min) (point-max) file)
+      (setq del-p t))
+    (setq shcmd (format "%s '%s'" Rd-to-help-command file))
     (set-buffer pbuf)
     (erase-buffer)
-    (shell-command (format "%s %s" Rd-to-help-command sbuf) t)
+    (ess-write-to-dribble-buffer
+     (format "Rd-preview-help: (shell-command |%s| t)" shcmd))
+    (shell-command shcmd t)
+    (setq ess-help-sec-regex ess-help-R-sec-regex
+          ess-help-sec-keys-alist ess-help-R-sec-keys-alist)
     (ess-nuke-help-bs)
     (ess-help-mode)
-    (if (not (get-buffer-window pbuf 'visible))
-	(display-buffer pbuf t))))
+    (when del-p (delete-file file))
+    (unless (get-buffer-window pbuf 'visible)
+      (display-buffer pbuf t))))
 
 ;; Bug reporting
 (defun Rd-submit-bug-report ()
