@@ -1,9 +1,11 @@
 ;;; ess-roxy.el --- convenient editing of in-code roxygen documentation
 ;;
-;; Copyright (C) 2009 Henning Redestig
+;; Copyright (C) 2009--2012 Henning Redestig, A.J. Rossini, Richard
+;;      M. Heiberger, Martin Maechler, Kurt Hornik, Rodney Sparapani, Stephen
+;;      Eglen and Vitalie Spinu.
 ;;
 ;; Author: Henning Redestig <henning.red * go0glemail c-m>
-;; Keywords: convenience tools
+;; Keywords: convenience, tools
 ;;
 ;; This file is part of ESS
 ;;
@@ -20,8 +22,10 @@
 ;; You should have received a copy of the GNU General Public License
 ;; along with this program.  If not, see
 ;; <http://www.gnu.org/licenses/>.
-;;
+
+
 ;;; Commentary:
+
 ;; Lots of inspiration from doc-mode,
 ;; http://nschum.de/src/emacs/doc-mode/
 ;;
@@ -42,7 +46,8 @@
 ;;     using roxygen
 ;;   - C-c C-e C-t :: create a preview of the Rd HTML file as generated
 ;;     using roxygen and the tools package
-;;     
+;;   - C-c C-e t :: create a preview of the Rd text file
+;;
 ;; Known issues:
 ;;
 ;; - hideshow mode does not work very well. In particular, if ordinary
@@ -50,12 +55,15 @@
 ;;   same overlay from start and not unfoldable using TAB since the
 ;;   roxygen prefix is not present. The planned solution is implement
 ;;   a replacement for hideshow.
-;; - only limited functionality for S4 documentation. 
+;; - only limited functionality for S4 documentation.
 
 ;; this *is* enabled now via ess-mode-hook in ./ess-site.el
 
+;;; Code:
+
 (require 'ess-custom)
 (require 'hideshow)
+(autoload 'Rd-preview-help "ess-rd" "[autoload]" t)
 
 ;; ------------------
 (defvar ess-roxy-mode-map nil
@@ -66,31 +74,31 @@
   (if ess-roxy-hide-show-p
       (define-key ess-roxy-mode-map (kbd "C-c C-e C-h") 'ess-roxy-hide-all))
   ;; short version (*first*: -> key binding shown in menu):
-  (define-key ess-roxy-mode-map (kbd "C-c C-o") 'ess-roxy-update-entry)
+  (define-key ess-roxy-mode-map (kbd "C-c C-o")     'ess-roxy-update-entry)
   (define-key ess-roxy-mode-map (kbd "C-c C-e n")   'ess-roxy-next-entry)
   (define-key ess-roxy-mode-map (kbd "C-c C-e p")   'ess-roxy-previous-entry)
   ;; For consistency (e.g. C-c C-e C-h !): kept here *in* addition to above
   (define-key ess-roxy-mode-map (kbd "C-c C-e C-o") 'ess-roxy-update-entry)
-  (define-key ess-roxy-mode-map (kbd "C-c C-e C-r")   'ess-roxy-preview-Rd)
-  (define-key ess-roxy-mode-map (kbd "C-c C-e C-t")   'ess-roxy-preview-HTML)
+  (define-key ess-roxy-mode-map (kbd "C-c C-e C-r") 'ess-roxy-preview-Rd)
+  (define-key ess-roxy-mode-map (kbd "C-c C-e C-t") 'ess-roxy-preview-HTML)
+  (define-key ess-roxy-mode-map (kbd "C-c C-e t")   'ess-roxy-preview-text)
   (define-key ess-roxy-mode-map (kbd "C-c C-e C-c") 'ess-roxy-toggle-roxy-region)
   )
 
-(defconst ess-roxy-font-lock-keywords
-  (eval-when-compile
-    `((,(concat ess-roxy-str " *\\([@\\]"
-		(regexp-opt ess-roxy-tags-param t)
-		"\\)\\>")
-       (1 'font-lock-keyword-face prepend))
-      (,(concat ess-roxy-str " *\\([@\\]"
-         (regexp-opt '("param") t)
-         "\\)\\>\\(?:[ \t]+\\(\\sw+\\)\\)?")
-       (1 'font-lock-keyword-face prepend)
-       (3 'font-lock-variable-name-face prepend))
-      (,(concat "[@\\]" (regexp-opt ess-roxy-tags-noparam t) "\\>")
-       (0 'font-lock-variable-name-face prepend))
-      (,(concat ess-roxy-str)
-       (0 'bold prepend)))))
+(defvar ess-roxy-font-lock-keywords
+  `((,(concat "^" ess-roxy-str " *\\([@\\]"
+              (regexp-opt ess-roxy-tags-param t)
+              "\\)\\>")
+     (1 'font-lock-keyword-face prepend))
+    (,(concat "^" ess-roxy-str " *\\([@\\]"
+              (regexp-opt '("param" "importFrom") t)
+              "\\)\\>\\(?:[ \t]+\\(\\sw+\\)\\)?")
+     (1 'font-lock-keyword-face prepend)
+     (3 'font-lock-variable-name-face prepend))
+    (,(concat "[@\\]" (regexp-opt ess-roxy-tags-noparam t) "\\>")
+     (0 'font-lock-variable-name-face prepend))
+    (,(concat "^" ess-roxy-str)
+     (0 'bold prepend))))
 
 (define-minor-mode ess-roxy-mode
   "Minor mode for editing in-code documentation."
@@ -98,24 +106,27 @@
   :keymap ess-roxy-mode-map
   (if ess-roxy-mode
       (progn
-	(unless (featurep 'xemacs) ;; does not exist in xemacs:
-	  (font-lock-add-keywords nil ess-roxy-font-lock-keywords))
-	(if ess-roxy-hide-show-p
-	    (progn
-	      ;(setq hs-c-start-regexp "s")
-	      (if (condition-case nil
-		      (if (and (symbolp hs-minor-mode)
-			       (symbol-value hs-minor-mode))
-			  nil t) (error t) )
-		  (progn
-		    (hs-minor-mode)))
-	      (if ess-roxy-start-hidden-p
-		  (ess-roxy-hide-all)))))
+        (unless (featurep 'xemacs) ;; does not exist in xemacs:
+          (font-lock-add-keywords nil ess-roxy-font-lock-keywords))
+        (if (and (featurep 'emacs) (>= emacs-major-version 24))
+            (add-to-list 'completion-at-point-functions 'ess-roxy-tag-completion)
+          (add-to-list 'comint-dynamic-complete-functions 'ess-roxy-complete-tag))
+        (if ess-roxy-hide-show-p
+            (progn
+                                        ;(setq hs-c-start-regexp "s")
+              (if (condition-case nil
+                      (if (and (symbolp hs-minor-mode)
+                               (symbol-value hs-minor-mode))
+                          nil t) (error t) )
+                  (progn
+                    (hs-minor-mode)))
+              (if ess-roxy-start-hidden-p
+                  (ess-roxy-hide-all)))))
     (if ess-roxy-hide-show-p
-	(if hs-minor-mode
-	    (progn
-	      (hs-show-all)
-	      (hs-minor-mode))))
+        (if hs-minor-mode
+            (progn
+              (hs-show-all)
+              (hs-minor-mode))))
     (unless (featurep 'xemacs)
       (font-lock-remove-keywords nil ess-roxy-font-lock-keywords)))
   (when font-lock-mode
@@ -133,12 +144,25 @@
       (beginning-of-line)
       (setq beg -1)
       (if (not (ess-roxy-entry-p))
-	  (setq beg 0)
-	(setq beg (point)))
+          (setq beg 0)
+        (setq beg (point)))
       (while (and (= (forward-line -1) 0) (ess-roxy-entry-p))
-	(setq beg (point)))
+        (setq beg (point)))
       beg)))
 
+(defun ess-roxy-in-header-p ()
+  "true if point is the description / details field"
+  (save-excursion
+    (let ((res t)
+          (cont (ess-roxy-entry-p)))
+      (beginning-of-line)
+      (while cont
+        (if (looking-at (concat "^" ess-roxy-str " *[@].+"))
+            (progn (setq res nil)
+                   (setq cont nil)))
+        (setq cont (and (= (forward-line -1) 0) (ess-roxy-entry-p)))
+        )res)))
+
 (defun ess-roxy-beg-of-field ()
   "Get point number at beginning of current field, 0 if not in entry"
   (save-excursion
@@ -147,15 +171,16 @@
       (setq beg 0)
       (setq cont t)
       (while (and (ess-roxy-entry-p) cont)
-	(setq beg (point))
-	(if (looking-at (concat "^" ess-roxy-str " *[@].+"))
-	    (setq cont nil))
-	(if (looking-at (concat "^" ess-roxy-str " *$"))
-	    (progn
-	      (forward-line 1)
-	      (setq beg (point))
-	      (setq cont nil)))
-	(if cont (setq cont (= (forward-line -1) 0))))
+        (setq beg (point))
+        (if (looking-at (concat "^" ess-roxy-str " *[@].+"))
+            (setq cont nil))
+        (if (ess-roxy-in-header-p)
+            (if (looking-at (concat "^" ess-roxy-str " *$"))
+                (progn
+                  (forward-line 1)
+                  (setq beg (point))
+                  (setq cont nil))))
+        (if cont (setq cont (= (forward-line -1) 0))))
       beg)))
 
 (defun ess-roxy-end-of-entry ()
@@ -165,33 +190,36 @@
       (end-of-line)
       (setq end -1)
       (if (not (ess-roxy-entry-p))
-	  (setq end 0)
-	(setq end (point)))
+          (setq end 0)
+        (setq end (point)))
       (while (and (= (forward-line 1) 0) (ess-roxy-entry-p))
-	(end-of-line)
-	(setq end (point)))
+        (end-of-line)
+        (setq end (point)))
       end)))
 
 (defun ess-roxy-end-of-field ()
   "get point number at end of current field, 0 if not in entry"
   (save-excursion
     (let ((end nil)
-	  (cont nil))
+          (cont nil))
       (setq end 0)
       (if (ess-roxy-entry-p) (progn (end-of-line) (setq end (point))))
       (beginning-of-line)
       (forward-line 1)
       (setq cont t)
       (while (and (ess-roxy-entry-p) cont)
-	(setq end (point))
-	(if (or (looking-at (concat "^" ess-roxy-str " *$"))
-		(looking-at (concat "^" ess-roxy-str " *[@].+")))
-	    (progn
-	      (forward-line -1)
-	      (end-of-line)
-	      (setq end (point))
-	      (setq cont nil)))
-	(if cont (setq cont (= (forward-line 1) 0))))
+        (save-excursion
+          (end-of-line)
+          (setq end (point)))
+        (if (or (and (ess-roxy-in-header-p)
+                     (looking-at (concat "^" ess-roxy-str " *$")))
+                (looking-at (concat "^" ess-roxy-str " *[@].+")))
+            (progn
+              (forward-line -1)
+              (end-of-line)
+              (setq end (point))
+              (setq cont nil)))
+        (if cont (setq cont (= (forward-line 1) 0))))
       end)))
 
 (defun ess-roxy-entry-p ()
@@ -204,27 +232,35 @@
   "Go to to the start of current field"
   (interactive)
   (let ((beg (ess-roxy-beg-of-field))
-	(end (ess-roxy-end-of-field)))
+        (end (ess-roxy-end-of-field)))
     (narrow-to-region beg end)))
 
 (defun ess-roxy-fill-field ()
-  "Fill the current roxygen field."
+  "Fill the current paragraph in the current roxygen field."
   (interactive)
   (if (ess-roxy-entry-p)
       (save-excursion
-	(let ((beg (ess-roxy-beg-of-field))
-	      (end (ess-roxy-end-of-field))
-	      (fill-prefix (concat ess-roxy-str " ")))
-	  (fill-region beg end nil t)))))
+        (let ((beg (ess-roxy-beg-of-field))
+              (end (ess-roxy-end-of-field))
+              (fill-prefix (concat ess-roxy-str " "))
+              (beg-par (point-min))
+              (end-par (point-max)))
+          (save-excursion
+            (if (re-search-backward (concat "^" ess-roxy-str " *$") beg t)
+                (setq beg-par (match-end 0))))
+          (save-excursion
+            (if (re-search-forward (concat "^" ess-roxy-str " *$") end t)
+                (setq end-par (- (match-beginning 0) 1))))
+          (fill-region (max beg beg-par) (min end end-par))))))
 
 (defun ess-roxy-goto-func-def ()
   "put point at start of function either that the point is in or
 below the current roxygen entry, error otherwise"
   (if (ess-roxy-entry-p)
       (progn
-	(ess-roxy-goto-end-of-entry)
-	(forward-line 1)
-	(beginning-of-line))
+        (ess-roxy-goto-end-of-entry)
+        (forward-line 1)
+        (beginning-of-line))
     (goto-char (car (ess-end-of-function)))))
 
 (defun ess-roxy-get-args-list-from-def ()
@@ -240,25 +276,25 @@ function at point. if here is supplied start inputting
 `here'. Finish at end of line."
   (let* ((arg-des nil))
     (if (or (not here) (< here 1))
-	(progn
-	  (ess-roxy-goto-end-of-entry)
-	  (beginning-of-line)
-	  (if (not (looking-at "\="))
-	      (progn
-		(end-of-line))))
+        (progn
+          (ess-roxy-goto-end-of-entry)
+          (beginning-of-line)
+          (if (not (looking-at "\="))
+              (progn
+                (end-of-line))))
       (goto-char here))
     (while (stringp (car (car args)))
       (setq arg-des (pop args))
       (unless (string= (car arg-des) "")
-	  (progn
-	    (insert (concat "\n"
-			    ess-roxy-str " @param " (car arg-des) " "))
-	    (insert 
-	     (ess-replace-in-string (concat (car (cdr arg-des))) "\n" 
-				    (concat "\n" ess-roxy-str)))
-	    (if ess-roxy-fill-param-p
-		(ess-roxy-fill-field))
-	    )))))
+        (progn
+          (insert (concat "\n"
+                          ess-roxy-str " @param " (car arg-des) " "))
+          (insert
+           (ess-replace-in-string (concat (car (cdr arg-des))) "\n"
+                                  (concat "\n" ess-roxy-str)))
+          (if ess-roxy-fill-param-p
+              (ess-roxy-fill-field))
+          )))))
 
 (defun ess-roxy-merge-args (fun ent)
   "Take two args lists (alists) and return their union. Result
@@ -267,17 +303,17 @@ association from ent are preferred over entries from fun. Also,
 drop entries from ent that are not in fun and are associated with
 the empty string."
   (let ((res-arg nil)
-	(arg-des))			
+        (arg-des))
     (while (stringp (car (car fun)))
       (setq arg-des (pop fun))
       (if (assoc (car arg-des) ent)
-	  (setq res-arg
-		(cons (cons (car arg-des) (cdr (assoc (car arg-des) ent))) res-arg))
-	(setq res-arg (cons (cons (car arg-des) '("")) res-arg))))
+          (setq res-arg
+                (cons (cons (car arg-des) (cdr (assoc (car arg-des) ent))) res-arg))
+        (setq res-arg (cons (cons (car arg-des) '("")) res-arg))))
     (while (stringp (car (car ent)))
       (setq arg-des (pop ent))
       (if (and (not (assoc (car arg-des) res-arg)) (not (string= (car (cdr arg-des)) "")))
-	  (setq res-arg (cons (cons (car arg-des) (cdr arg-des)) res-arg))))
+          (setq res-arg (cons (cons (car arg-des) (cdr arg-des)) res-arg))))
     (nreverse res-arg)))
 
 (defun ess-roxy-update-entry ()
@@ -290,38 +326,38 @@ non-nil."
   (interactive)
   (save-excursion
     (let* ((args-fun (ess-roxy-get-args-list-from-def))
-	   (args-ent (ess-roxy-get-args-list-from-entry))
-	   (args (ess-roxy-merge-args args-fun args-ent))
-	   (line-break "")
-	   here key template tag-def)
+           (args-ent (ess-roxy-get-args-list-from-entry))
+           (args (ess-roxy-merge-args args-fun args-ent))
+           (line-break "")
+           here key template tag-def)
       (ess-roxy-goto-func-def)
       (if (not (= (forward-line -1) 0))
-      	  (progn
-	    (insert "\n")
-	    (forward-line -1)))
+          (progn
+            (insert "\n")
+            (forward-line -1)))
       (if (and (not (looking-at "^\n")) (not (ess-roxy-entry-p)))
-	  (progn
-	    (end-of-line)
-	    (insert "\n")))
+          (progn
+            (end-of-line)
+            (insert "\n")))
       (if (ess-roxy-entry-p)
-	  (progn
-	    (setq here (1- (ess-roxy-delete-args)))
-	    (ess-roxy-insert-args args here))
-	(setq template (copy-sequence ess-roxy-template-alist))
-	(while (stringp (car (car template)))
-	  (setq tag-def (pop template))
-	  (if (string= (car tag-def) "param")
-	      (ess-roxy-insert-args args (point))
-	    (if (string= (car tag-def) "description")
-		(insert (concat line-break ess-roxy-str " "
-				(cdr tag-def) "\n" ess-roxy-str))
-	      (if (string= (car tag-def) "details")
-		  (insert (concat line-break ess-roxy-str " " (cdr tag-def)))
-		(insert (concat line-break ess-roxy-str " @"
-				(car tag-def) " " (cdr tag-def))))
-		))
-	  (setq line-break "\n")
-	  )))))
+          (progn
+            (setq here (1- (ess-roxy-delete-args)))
+            (ess-roxy-insert-args args here))
+        (setq template (copy-sequence ess-roxy-template-alist))
+        (while (stringp (car (car template)))
+          (setq tag-def (pop template))
+          (if (string= (car tag-def) "param")
+              (ess-roxy-insert-args args (point))
+            (if (string= (car tag-def) "description")
+                (insert (concat line-break ess-roxy-str " "
+                                (cdr tag-def) "\n" ess-roxy-str))
+              (if (string= (car tag-def) "details")
+                  (insert (concat line-break ess-roxy-str " " (cdr tag-def)))
+                (insert (concat line-break ess-roxy-str " @"
+                                (car tag-def) " " (cdr tag-def))))
+              ))
+          (setq line-break "\n")
+          )))))
 
 (defun ess-roxy-goto-end-of-entry ()
   "Put point at the top of the entry at point or above the
@@ -330,12 +366,12 @@ entry, otherwise nil. Error if point is not in function or
 roxygen entry."
   (if (not (ess-roxy-entry-p))
       (progn
-	(goto-char (nth 0 (ess-end-of-function)))
-	(forward-line -1)))
+        (goto-char (nth 0 (ess-end-of-function)))
+        (forward-line -1)))
   (if (ess-roxy-entry-p)
       (progn
-	(goto-char (ess-roxy-end-of-entry))
-	t) (forward-line) nil))
+        (goto-char (ess-roxy-end-of-entry))
+        t) (forward-line) nil))
 
 (defun ess-roxy-goto-beg-of-entry ()
   "put point at the top of the entry at point or above the
@@ -344,12 +380,12 @@ entry, otherwise nil. Error if point is not in function or
 roxygen entry."
   (if (not (ess-roxy-entry-p))
       (progn
-	(goto-char (nth 0 (ess-end-of-function)))
-	(forward-line -1)))
+        (goto-char (nth 0 (ess-end-of-function)))
+        (forward-line -1)))
   (if (ess-roxy-entry-p)
       (progn
-	(goto-char (ess-roxy-beg-of-entry))
-	t) (forward-line) nil))
+        (goto-char (ess-roxy-beg-of-entry))
+        t) (forward-line) nil))
 
 (defun ess-roxy-delete-args ()
   "remove all args from the entry at point or above the function
@@ -357,24 +393,24 @@ at point. Return 0 if no deletions were made other wise the point
 at where the last deletion ended"
   (save-excursion
     (let* ((args nil)
-	   (cont t)
-	   (field-beg 0)
-	   entry-beg entry-end field-end)
+           (cont t)
+           (field-beg 0)
+           entry-beg entry-end field-end)
       (ess-roxy-goto-end-of-entry)
       (setq entry-beg (ess-roxy-beg-of-entry))
       (setq entry-end (ess-roxy-end-of-entry))
       (goto-char entry-end)
       (beginning-of-line)
       (while (and (<= entry-beg (point)) (> entry-beg 0) cont)
-	(if (looking-at
-	     (concat "^" ess-roxy-str " *@param"))
-	    (progn
-	      (setq field-beg (ess-roxy-beg-of-field))
-	      (setq field-end (ess-roxy-end-of-field))
-	      (delete-region field-beg (+ field-end 1))))
-	(setq cont nil)
-	(if (= (forward-line -1) 0)
-	    (setq cont t)))
+        (if (looking-at
+             (concat "^" ess-roxy-str " *@param"))
+            (progn
+              (setq field-beg (ess-roxy-beg-of-field))
+              (setq field-end (ess-roxy-end-of-field))
+              (delete-region field-beg (+ field-end 1))))
+        (setq cont nil)
+        (if (= (forward-line -1) 0)
+            (setq cont t)))
       field-beg)))
 
 (defun ess-roxy-get-args-list-from-entry ()
@@ -382,36 +418,36 @@ at where the last deletion ended"
 point is"
   (save-excursion
     (let* (args entry-beg field-beg field-end args-text arg-name
-	   desc)
+                desc)
       (if (ess-roxy-goto-end-of-entry)
-	  (progn
-	    (beginning-of-line)
-	    (setq entry-beg (ess-roxy-beg-of-entry))
-	    (while (and (< entry-beg (point)) (> entry-beg 0))
-	      (if (looking-at
-		   (concat "^" ess-roxy-str " *@param"))
-		  (progn
-		    (setq field-beg (ess-roxy-beg-of-field))
-		    (setq field-end (ess-roxy-end-of-field))
-		    (setq args-text (buffer-substring-no-properties
-				     field-beg field-end))
-		    (setq args-text
-		    	  (ess-replace-in-string args-text
-		    				 ess-roxy-str ""))
-		    (setq args-text
-			  (ess-replace-in-string
-			   args-text "[[:space:]]*@param *" ""))
-		    ;; (setq args-text
-		    ;; 	  (ess-replace-in-string args-text "\n" ""))
-		    (string-match "[^[:space:]]*" args-text)
-		    (setq arg-name (match-string 0 args-text))
-		    (setq desc (replace-regexp-in-string
-				(concat "^" arg-name " *") "" args-text))
-		    (setq args (cons (list (concat arg-name)
-					   (concat desc)) args))))
-	      (forward-line -1))
-	    args)
-	nil))))
+          (progn
+            (beginning-of-line)
+            (setq entry-beg (ess-roxy-beg-of-entry))
+            (while (and (< entry-beg (point)) (> entry-beg 0))
+              (if (looking-at
+                   (concat "^" ess-roxy-str " *@param"))
+                  (progn
+                    (setq field-beg (ess-roxy-beg-of-field))
+                    (setq field-end (ess-roxy-end-of-field))
+                    (setq args-text (buffer-substring-no-properties
+                                     field-beg field-end))
+                    (setq args-text
+                          (ess-replace-in-string args-text
+                                                 ess-roxy-str ""))
+                    (setq args-text
+                          (ess-replace-in-string
+                           args-text "[[:space:]]*@param *" ""))
+                    ;; (setq args-text
+                    ;;    (ess-replace-in-string args-text "\n" ""))
+                    (string-match "[^[:space:]]*" args-text)
+                    (setq arg-name (match-string 0 args-text))
+                    (setq desc (replace-regexp-in-string
+                                (concat "^" (regexp-quote arg-name) " *") "" args-text))
+                    (setq args (cons (list (concat arg-name)
+                                           (concat desc)) args))))
+              (forward-line -1))
+            args)
+        nil))))
 
 (defun ess-roxy-toggle-roxy-region (beg end)
   "Remove prefix roxy string in this region if point is in a roxy
@@ -420,46 +456,57 @@ string. Convenient for editing example fields."
   (interactive "r")
   (condition-case nil
       (if (not (ess-roxy-mark-active))
-  	  (error "region is not active")))
+          (error "region is not active")))
+  (ess-roxy-roxy-region beg end (ess-roxy-entry-p)))
+
+(defun ess-roxy-roxy-region (beg end &optional on)
   (save-excursion
     (let (RE to-string)
       (narrow-to-region beg (- end 1))
-      (if (ess-roxy-entry-p)
-	  (progn (setq RE (concat "^" ess-roxy-str " *"))
-		 (setq to-string ""))
-	(setq RE "^")
-	(setq to-string (concat ess-roxy-str " ")))
+      (if on
+          (progn (setq RE (concat "^" ess-roxy-str " *"))
+                 (setq to-string ""))
+        (setq RE "^")
+        (setq to-string (concat ess-roxy-str " ")))
       (goto-char beg)
       (while (re-search-forward RE (point-max) 'noerror)
-	(replace-match to-string))
+        (replace-match to-string))
       (widen))))
 
 (defun ess-roxy-preview ()
-  "Use the connected R session and the roxygen package to
-generate the Rd code for entry at point, place it in a temporary
-buffer and return that buffer."
+  "Use the connected R session and the roxygen package `ess-roxy-package'
+to generate the Rd code for entry at point, place it in
+a temporary buffer and return that buffer."
   (let ((beg (ess-roxy-beg-of-entry))
-	(roxy-tmp (make-temp-file "ess-roxy"))
-	(roxy-buf (get-buffer-create " *RoxygenPreview*")))
+        (tmpf (make-temp-file "ess-roxy"))
+        (roxy-buf (get-buffer-create " *RoxygenPreview*"))
+        (out-rd-roclet
+         (cond ((string= "roxygen" ess-roxy-package)
+                "make.Rd2.roclet()$parse")
+               ((string= "roxygen2" ess-roxy-package)
+                "(function(P) {..results <- roxygen2:::roc_process(rd_roclet(), parse.files(P), \"\");cat(vapply(..results, FUN.VALUE = character(1), function(x) {roxygen2:::rd_out_cache$compute(x, format(x))}))})")
+               (t (error "need to hard code the roclet output call for roxygen package '%s'"
+                         ess-roxy-package))))
+        )
     (if (= beg 0)
-	(error "Point is not in a Roxygen entry"))
+        (error "Point is not in a Roxygen entry"))
     (save-excursion
       (goto-char (ess-roxy-end-of-entry))
       (forward-line 1)
       (if (ess-end-of-function nil t)
-	  (append-to-file beg (point) roxy-tmp)
-	(while (and (forward-line 1) (not (looking-at "^$")) 
-		    (not (looking-at ess-roxy-str))))
-	(append-to-file beg (point) roxy-tmp))
-      (ess-command "print(suppressWarnings(require(roxygen, quietly=TRUE)))\n"
-		   roxy-buf)
+          (append-to-file beg (point) tmpf)
+        (while (and (forward-line 1) (not (looking-at "^$"))
+                    (not (looking-at ess-roxy-str))))
+        (append-to-file beg (point) tmpf))
+      (ess-command (concat "print(suppressWarnings(require(" ess-roxy-package
+                           ", quietly=TRUE)))\n") roxy-buf)
       (with-current-buffer roxy-buf
-	(goto-char 1)
-	(if (search-forward-regexp "FALSE" nil t)
-	    (error (concat "Failed to load the roxygen package; "
-			   "in R, try  install.packages(\"roxygen\")"))))
-      (ess-command (concat "make.Rd.roclet()$parse(\"" roxy-tmp "\")\n") roxy-buf))
-    (delete-file roxy-tmp)
+        (goto-char 1)
+        (if (search-forward-regexp "FALSE" nil t)
+            (error (concat "Failed to load the " ess-roxy-package " package; "
+                           "in R, try  install.packages(\"" ess-roxy-package "\")"))))
+      (ess-command (concat out-rd-roclet "(\"" tmpf "\")\n") roxy-buf))
+    ;;(delete-file tmpf)
     roxy-buf))
 
 (defun ess-roxy-preview-HTML (&optional visit-instead-of-open)
@@ -468,22 +515,30 @@ generate a HTML page for the roxygen entry at point and open that
 buffer in a browser. Visit the HTML file instead of showing it in
 a browser if `visit-instead-of-open' is non-nil"
   (interactive "P")
-  (let ((roxy-buf (ess-roxy-preview))
-	(rd-tmp-file (make-temp-file "ess-roxy-" nil ".Rd"))
-	(html-tmp-file (make-temp-file "ess-roxy-" nil ".html")))
+  (let* ((roxy-buf (ess-roxy-preview))
+         (rd-tmp-file (make-temp-file "ess-roxy-" nil ".Rd"))
+         (html-tmp-file (make-temp-file "ess-roxy-" nil ".html"))
+         (rd-to-html (concat "Rd2HTML(\"" rd-tmp-file "\",\""
+                             html-tmp-file "\", stages=c(\"render\"))"))
+         )
     (with-current-buffer roxy-buf
       (set-visited-file-name rd-tmp-file)
       (save-buffer)
       (kill-buffer roxy-buf))
     (ess-command "print(suppressWarnings(require(tools, quietly=TRUE)))\n")
-    (if (not visit-instead-of-open)
-	(ess-command 
-	 (concat "browseURL(Rd2HTML(\"" rd-tmp-file "\",\"" 
-		 html-tmp-file "\", stages=c(\"render\")))\n"))
-      (ess-command 
-       (concat "Rd2HTML(\"" rd-tmp-file "\",\"" 
-	       html-tmp-file "\", stages=c(\"render\"))\n"))
-      (find-file html-tmp-file))))
+    (ess-command
+     (if visit-instead-of-open
+         (concat rd-to-html "\n")
+       (concat "browseURL(" rd-to-html ")\n")))
+    (find-file html-tmp-file)))
+
+
+(defun ess-roxy-preview-text ()
+  "Use the connected R session and the roxygen package to
+generate the text help page of the roxygen entry at point."
+  (interactive)
+  (with-current-buffer (ess-roxy-preview)
+    (Rd-preview-help)))
 
 (defun ess-roxy-preview-Rd (&optional name-file)
   "Use the connected R session and the roxygen package to
@@ -495,10 +550,10 @@ facilitate saving that file."
   (let ((roxy-buf (ess-roxy-preview)))
     (pop-to-buffer roxy-buf)
     (if name-file
-	(save-excursion
-	  (goto-char 1)
-	  (search-forward-regexp "name{\\(.+\\)}")
-	  (set-visited-file-name (concat (match-string 1) ".Rd"))))
+        (save-excursion
+          (goto-char 1)
+          (search-forward-regexp "name{\\(.+\\)}")
+          (set-visited-file-name (concat (match-string 1) ".Rd"))))
     (Rd-mode)))
 
 (defun ess-roxy-mark-active ()
@@ -512,9 +567,9 @@ facilitate saving that file."
   (interactive)
   (save-excursion
     (goto-char (point-min))
-    (while (search-forward ess-roxy-str (point-max) t 1)
+    (while (re-search-forward (concat "^" ess-roxy-str) (point-max) t 1)
       (if (not (hs-already-hidden-p))
-	  (hs-hide-block))
+          (hs-hide-block))
       (goto-char (ess-roxy-end-of-entry))
       (forward-line 1))))
 
@@ -523,8 +578,8 @@ facilitate saving that file."
   (interactive)
   (if (ess-roxy-entry-p)
       (progn
-	(goto-char (ess-roxy-beg-of-entry))
-	(forward-line -1)))
+        (goto-char (ess-roxy-beg-of-entry))
+        (forward-line -1)))
   (search-backward ess-roxy-str (point-min) t 1)
   (goto-char (ess-roxy-beg-of-entry)))
 
@@ -533,8 +588,8 @@ facilitate saving that file."
   (interactive)
   (if (ess-roxy-entry-p)
       (progn
-	(goto-char (ess-roxy-end-of-entry))
-	(forward-line 1)))
+        (goto-char (ess-roxy-end-of-entry))
+        (forward-line 1)))
   (search-forward ess-roxy-str (point-max) t 1)
   (goto-char (ess-roxy-beg-of-entry)))
 
@@ -543,15 +598,15 @@ facilitate saving that file."
 list of strings."
   (save-excursion
     (let ((args-txt
-	   (progn
-	     (ess-beginning-of-function)
-	     (buffer-substring-no-properties
-	      (progn
-		(search-forward-regexp "\\([=,-]+ *function *\\|^\s*function\\)" nil nil 1)
-		(+ (point) 1))
-	      (progn
-		(ess-roxy-match-paren)
-		(point))))))
+           (progn
+             (ess-beginning-of-function)
+             (buffer-substring-no-properties
+              (progn
+                (search-forward-regexp "\\([=,-]+ *function *\\|^\s*function\\)" nil nil 1)
+                (+ (point) 1))
+              (progn
+                (ess-roxy-match-paren)
+                (point))))))
       (setq args-txt (replace-regexp-in-string "#+.*\n" "" args-txt))
       (setq args-txt (replace-regexp-in-string "([^)]+)" "" args-txt))
       (setq args-txt (replace-regexp-in-string "=[^,]+" "" args-txt))
@@ -566,39 +621,37 @@ list of strings."
 (defun ess-roxy-complete-tag ()
   "complete the tag at point"
   (let ((token-string (thing-at-point 'symbol)))
-    (if (string-match "@.+" token-string)
-	(progn
-	  (comint-dynamic-simple-complete
-	   (replace-regexp-in-string "^@" "" token-string)
-	   (append ess-roxy-tags-noparam ess-roxy-tags-param))))))
+    (when (and token-string (string-match "@.+" token-string))
+      (comint-dynamic-simple-complete
+       (replace-regexp-in-string "^@" "" token-string)
+       (append ess-roxy-tags-noparam ess-roxy-tags-param)))))
+
+(defun ess-roxy-tag-completion ()
+  "Completion data for emacs >= 24"
+  (when (save-excursion (re-search-backward "@\\<\\(\\w*\\)" (point-at-bol) t))
+    (let ((token (match-string-no-properties 1))
+          (beg (match-beginning 1))
+          (end (match-end 1)))
+      (when (and end (= end (point)))
+        (list beg end (append ess-roxy-tags-noparam ess-roxy-tags-param) :exclusive 'no)))))
 
 ;; advices
-(defadvice ess-R-complete-object-name (around ess-roxy-complete-tag)
-  (if (ess-roxy-entry-p)
-      (ess-roxy-complete-tag)
-    ad-do-it))
-(defadvice ess-internal-complete-object-name (around ess-roxy-complete-tag)
-  (if (ess-roxy-entry-p)
-      (ess-roxy-complete-tag)
-    ad-do-it))
-(ad-activate 'ess-internal-complete-object-name)
-(ad-activate 'ess-R-complete-object-name)
-
 (defadvice mark-paragraph (around ess-roxy-mark-field)
   "mark this field"
   (if (and (ess-roxy-entry-p) (not mark-active))
       (progn
-	(push-mark (point))
-	(push-mark (1+ (ess-roxy-end-of-field)) nil t)
-	(goto-char (ess-roxy-beg-of-field)))
+        (push-mark (point))
+        (push-mark (1+ (ess-roxy-end-of-field)) nil t)
+        (goto-char (ess-roxy-beg-of-field)))
     ad-do-it))
 (ad-activate 'mark-paragraph)
 
 (defadvice ess-indent-command (around ess-roxy-toggle-hiding)
   "hide this block if we are at the beginning of the line"
-  (if (and (ess-roxy-entry-p) 'ess-roxy-hide-show-p)
+  (if (and (= (point) (point-at-bol)) (ess-roxy-entry-p) 'ess-roxy-hide-show-p)
       (progn (hs-toggle-hiding))
     ad-do-it))
+
 (if ess-roxy-hide-show-p
     (ad-activate 'ess-indent-command))
 
@@ -612,11 +665,11 @@ list of strings."
 (defadvice move-beginning-of-line (around ess-roxy-beginning-of-line)
   "move to start"
   (if (and (ess-roxy-entry-p)
-	   (not (looking-back (concat ess-roxy-str " *\\="))))
+           (not (looking-back (concat ess-roxy-str " *\\="))))
       (progn
-	(end-of-line)
-	(re-search-backward (concat ess-roxy-str " *") (point-at-bol))
-	(goto-char (match-end 0)))
+        (end-of-line)
+        (re-search-backward (concat ess-roxy-str " *") (point-at-bol))
+        (goto-char (match-end 0)))
     ad-do-it))
 (ad-activate 'move-beginning-of-line)
 
@@ -624,9 +677,11 @@ list of strings."
   "Insert a newline in a roxygen field."
   (if (ess-roxy-entry-p)
       (progn
-	ad-do-it
-	(insert (concat ess-roxy-str " ")))
+        ad-do-it
+        (insert (concat ess-roxy-str " ")))
     ad-do-it))
 (ad-activate 'newline-and-indent)
 
 (provide 'ess-roxy)
+
+;;; ess-roxy.el ends here
