@@ -2,13 +2,13 @@
 
 ;; Copyright (C) 1997--2001 Richard M. Heiberger and A. J. Rossini
 ;; Copyright (C) 2002--2004 A.J. Rossini, Rich M. Heiberger, Martin
-;;	Maechler, Kurt Hornik, Rodney Sparapani, and Stephen Eglen.
+;;      Maechler, Kurt Hornik, Rodney Sparapani, and Stephen Eglen.
 
-;; Original Author: Richard M. Heiberger <rmh@astro.ocis.temple.edu>
+;; Author: Richard M. Heiberger <rmh@astro.ocis.temple.edu>
 ;; Created: 20 Aug 1997
-;; Maintainers: ESS-core <ESS-core@r-project.org>
+;; Maintainer: ESS-core <ESS-core@r-project.org>
 
-;; Keywords: start up, configuration.
+;; Keywords: languages
 
 ;; This file is part of ESS.
 
@@ -27,9 +27,11 @@
 ;; the Free Software Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.
 
 ;;; Commentary:
+
 ;; This file defines all the SAS customizations for ESS behaviors.  See
 ;; ess-sas-l and ess-sas-a for the underlying general modifications.
 
+;;; Code:
 
 ;;; Autoloads:
 
@@ -44,7 +46,6 @@
 (require 'ess-sas-l)
 (ess-message "[ess-sas-d:] (autoload ..) (def** ..) ...")
 
-
 (autoload 'inferior-ess "ess-inf" no-doc t)
 (autoload 'ess-mode "ess-mode" no-doc t)
 (autoload 'ess-proc-name "ess-inf" no-doc nil)
@@ -56,51 +57,49 @@
   "Hack variable, needed for args preprocessing.
 Better logic needed!  (see 2 uses, in this file).")
 
-;;; Code:
-
 (defun ess-SAS-pre-run-hook (temp-ess-dialect)
   "Set up log and list files for interactive SAS."
 
   (let* ((ess-shell-buffer-name-flag (get-buffer "*shell*"))
-	 ess-shell-buffer-name
-	 ;; isn't pretty yet.
-	 ;;  ess-local-process-name is defined after this function.
-	 ;;  it needs to be defined prior to this function.
-	 (tmp-procname (let ((ntry 0)
-			     (done nil))
-			 ;; find a non-existent process
-			 (while (not done)
-			   (setq ntry (1+ ntry)
-				 done (not
-				       (get-process (ess-proc-name
-						     ntry
-						     temp-ess-dialect)))))
-			 (ess-proc-name ntry temp-ess-dialect)))
-	 ;; Following was tmp-local-process-name.  Stolen from inferior-ess
-	 (ess-sas-lst-bufname (concat "*" tmp-procname ".lst*"))
-	 (ess-sas-log-bufname (concat "*" tmp-procname ".log*"))
-	 (explicit-shell-file-name "/bin/sh")
-	 inferior-SAS-redirect-args
-	 ess-sas-lst
-	 ess-sas-log)
+         ess-shell-buffer-name
+         ;; isn't pretty yet.
+         ;;  ess-local-process-name is defined after this function.
+         ;;  it needs to be defined prior to this function.
+         (tmp-procname (let ((ntry 0)
+                             (done nil))
+                         ;; find a non-existent process
+                         (while (not done)
+                           (setq ntry (1+ ntry)
+                                 done (not
+                                       (get-process (ess-proc-name
+                                                     ntry
+                                                     temp-ess-dialect)))))
+                         (ess-proc-name ntry temp-ess-dialect)))
+         ;; Following was tmp-local-process-name.  Stolen from inferior-ess
+         (ess-sas-lst-bufname (concat "*" tmp-procname ".lst*"))
+         (ess-sas-log-bufname (concat "*" tmp-procname ".log*"))
+         (explicit-shell-file-name "/bin/sh")
+         inferior-SAS-redirect-args
+         ess-sas-lst
+         ess-sas-log)
 
     (ess-write-to-dribble-buffer
      (format "(ess-SAS-pre-run-hook 1): ess-lang=%s, ess-dialect=%s, temp-dialect=%s, buf=%s \n"
-	     ess-language
-	     ess-dialect
-	     temp-ess-dialect
-	     (current-buffer)))
+             ess-language
+             ess-dialect
+             temp-ess-dialect
+             (current-buffer)))
     ;; If someone is running a *shell* buffer, rename it to avoid
     ;; inadvertent nuking.
     (if ess-shell-buffer-name-flag
-	(save-excursion
-	  (set-buffer "*shell*")
-	  (setq ess-shell-buffer-name
-		(rename-buffer "*ess-shell-regular*" t))))
+        (save-excursion
+          (set-buffer "*shell*")
+          (setq ess-shell-buffer-name
+                (rename-buffer "*ess-shell-regular*" t))))
 
     ;; Construct the LST buffer for output
     (if (get-buffer ess-sas-lst-bufname)
-	nil
+        nil
       (shell)
       (accept-process-output (get-buffer-process (current-buffer)))
       (sleep-for 2) ; need to wait, else working too fast!
@@ -110,31 +109,31 @@ Better logic needed!  (see 2 uses, in this file).")
       (ess-listing-minor-mode t)
       (rename-buffer ess-sas-lst-bufname t))
 
-     ;; Construct the LOG buffer for output
+    ;; Construct the LOG buffer for output
     (if (get-buffer  ess-sas-log-bufname)
-	nil
+        nil
       (shell)
       (accept-process-output (get-buffer-process (current-buffer)))
       (sleep-for 2) ; need to wait, else working too fast!
       (setq ess-sas-log (ess-insert-accept "tty"))
-      ;(SAS-log-mode)
+                                        ;(SAS-log-mode)
       (shell-mode)
       (ess-transcript-minor-mode t)
       (rename-buffer ess-sas-log-bufname t))
 
     (setq inferior-SAS-redirect-args (concat " "
-					     ess-sas-lst
-					     " "
-					     ess-sas-log
-					     " ")
-	  inferior-SAS-args-temp (concat inferior-SAS-redirect-args
-					 inferior-SAS-args))
+                                             ess-sas-lst
+                                             " "
+                                             ess-sas-log
+                                             " ")
+          inferior-SAS-args-temp (concat inferior-SAS-redirect-args
+                                         inferior-SAS-args))
 
     ;; Restore the *shell* buffer
     (if ess-shell-buffer-name-flag
-	(save-excursion
-	  (set-buffer ess-shell-buffer-name)
-	  (rename-buffer "*shell*")))
+        (save-excursion
+          (set-buffer ess-shell-buffer-name)
+          (rename-buffer "*shell*")))
 
     (delete-other-windows)
     (split-window-vertically)
@@ -149,8 +148,8 @@ Better logic needed!  (see 2 uses, in this file).")
 
     ;;workaround
     (setq inferior-SAS-program-name
-	  (concat (file-name-as-directory ess-etc-directory)
-		  "ess-sas-sh-command"))
+          (concat (file-name-as-directory ess-etc-directory)
+                  "ess-sas-sh-command"))
     (setq inferior-ess-program inferior-SAS-program-name)))
 
 (defun ess-insert-accept (command)
@@ -162,7 +161,7 @@ Better logic needed!  (see 2 uses, in this file).")
   (accept-process-output (get-buffer-process (current-buffer)))
   (forward-line -1)
   (let* ((beg (point))
-	 (ess-tty-name (progn (end-of-line) (buffer-substring beg (point)))))
+         (ess-tty-name (progn (end-of-line) (buffer-substring beg (point)))))
     (goto-char (point-max))
     ess-tty-name))
 
@@ -183,7 +182,7 @@ Better logic needed!  (see 2 uses, in this file).")
     (ess-loop-timeout              .  500000 )
     (inferior-ess-primary-prompt   . "^")
     (inferior-ess-secondary-prompt . "^")
-    (comint-use-prompt-regexp-instead-of-fields . t) ;; emacs 21 and up
+    (comint-use-prompt-regexp      . t)
     (inferior-ess-start-file       . nil) ;"~/.ess-SAS")
     (inferior-ess-start-args       . inferior-SAS-args-temp)
     (inferior-ess-font-lock-keywords . SAS-mode-font-lock-keywords)
@@ -213,22 +212,22 @@ Better logic needed!  (see 2 uses, in this file).")
   (define-key sas-mode-local-map "\C-ci" 'ess-eval-line-and-step-invisibly)
   (define-key sas-mode-local-map ";" 'ess-electric-run-semicolon)
 
-; this is a mess
-; interactive and batch commands share sas-mode-local-map,
-; but the associated commands are very different
-; what would be better is two maps like
-; sas-batch-mode-local-map and sas-interactive-mode-local-map
-; or smart function definitions that would do the appropriate
-; thing for either batch or interactive sessions
-; however, neither of these solutions are planned
-; therefore, no key definitions can be shared between
-; batch and interactive at this time, hence the lines that
-; are commented below:  uncomment at your own risk
-;  (define-key sas-mode-local-map "\C-c\C-p" 'ess-sas-file-path)
-;  (define-key sas-mode-local-map "\C-c\C-b" 'ess-sas-submit)
-;  (define-key sas-mode-local-map "\C-c\C-r" 'ess-sas-submit-region)
-;  (define-key sas-mode-local-map "\C-c\C-x" 'ess-sas-goto-log)
-;  (define-key sas-mode-local-map "\C-c\C-y" 'ess-sas-goto-lst)
+                                        ; this is a mess
+                                        ; interactive and batch commands share sas-mode-local-map,
+                                        ; but the associated commands are very different
+                                        ; what would be better is two maps like
+                                        ; sas-batch-mode-local-map and sas-interactive-mode-local-map
+                                        ; or smart function definitions that would do the appropriate
+                                        ; thing for either batch or interactive sessions
+                                        ; however, neither of these solutions are planned
+                                        ; therefore, no key definitions can be shared between
+                                        ; batch and interactive at this time, hence the lines that
+                                        ; are commented below:  uncomment at your own risk
+                                        ;  (define-key sas-mode-local-map "\C-c\C-p" 'ess-sas-file-path)
+                                        ;  (define-key sas-mode-local-map "\C-c\C-b" 'ess-sas-submit)
+                                        ;  (define-key sas-mode-local-map "\C-c\C-r" 'ess-sas-submit-region)
+                                        ;  (define-key sas-mode-local-map "\C-c\C-x" 'ess-sas-goto-log)
+                                        ;  (define-key sas-mode-local-map "\C-c\C-y" 'ess-sas-goto-lst)
 
   (use-local-map sas-mode-local-map)
 
@@ -239,7 +238,7 @@ Better logic needed!  (see 2 uses, in this file).")
   ;; font-lock-keywords-case-fold-search, but it fails for Emacs 22.[23]
   ;; hence :
   (setq font-lock-keywords-case-fold-search t)
-)
+  )
 
 
 
@@ -248,26 +247,26 @@ Better logic needed!  (see 2 uses, in this file).")
   "Insert character.  If the line contains \"run;\" and nothing else then indent line."
   (interactive "P")
   (if ess-sas-edit-keys-toggle (insert ";") (let (insertpos)
-    (if (and (not arg)
-	     (eolp)
-	     (save-excursion
-		   (skip-chars-backward " \t")
-		   (backward-word 1)
-		   (and (looking-at "run")
-			(progn
-			      (skip-chars-backward " \t")
-			  (bolp)))))
-	(progn
-	  (insert last-command-event)
-	  (ess-indent-line)
-	  (save-excursion
-	    (if insertpos (goto-char (1+ insertpos)))
-	    (delete-char -1))))
-    (if insertpos
-	(save-excursion
-	  (goto-char insertpos)
-	  (self-insert-command (prefix-numeric-value arg)))
-      (self-insert-command (prefix-numeric-value arg))))))
+                                              (if (and (not arg)
+                                                       (eolp)
+                                                       (save-excursion
+                                                         (skip-chars-backward " \t")
+                                                         (backward-word 1)
+                                                         (and (looking-at "run")
+                                                              (progn
+                                                                (skip-chars-backward " \t")
+                                                                (bolp)))))
+                                                  (progn
+                                                    (insert last-command-event)
+                                                    (ess-indent-line)
+                                                    (save-excursion
+                                                      (if insertpos (goto-char (1+ insertpos)))
+                                                      (delete-char -1))))
+                                              (if insertpos
+                                                  (save-excursion
+                                                    (goto-char insertpos)
+                                                    (self-insert-command (prefix-numeric-value arg)))
+                                                (self-insert-command (prefix-numeric-value arg))))))
 
 (defun SAS ()
   "Call 'SAS', from SAS Institute."
@@ -276,8 +275,8 @@ Better logic needed!  (see 2 uses, in this file).")
   (let* ((temp-dialect "SAS")) ;(cdr (rassoc ess-dialect SAS-customize-alist))))
     (ess-write-to-dribble-buffer
      (format "(SAS): ess-dial=%s, temp-dial=%s\n"
-	     ess-dialect
-	     temp-dialect))
+             ess-dialect
+             temp-dialect))
     (ess-SAS-pre-run-hook temp-dialect)
     (inferior-ess)
     (save-excursion
@@ -297,15 +296,18 @@ their own frames."
   (interactive)
   (delete-other-windows)
   (save-excursion
-      (set-buffer "*SAS*")
-      (make-frame)
-      (set-buffer "*SAS.log*")
-      (make-frame)
-      (set-buffer "*SAS.lst*")
-      (make-frame)))
+    (set-buffer "*SAS*")
+    (make-frame)
+    (set-buffer "*SAS.log*")
+    (make-frame)
+    (set-buffer "*SAS.lst*")
+    (make-frame)))
 
 
-(define-key ess-mode-map "\C-c\C-w"        'ess-multi-frame-SAS)
+(add-hook 'ess-mode-hook
+          (lambda ()
+            (when (string= ess-language "SAS") ;; e.g. not for R-only users
+              (local-set-key "\C-c\C-w" 'ess-multi-frame-SAS))))
 
  ; Provide package
 
