@@ -1,13 +1,13 @@
 ;;; ess-sp6-d.el --- S-Plus 6 & 7 & 8  customization
 
 ;; Copyright (C) 2001--2005 A.J. Rossini, Rich M. Heiberger, Martin
-;;	Maechler, Kurt Hornik, Rodney Sparapani, and Stephen Eglen.
+;;      Maechler, Kurt Hornik, Rodney Sparapani, and Stephen Eglen.
 
-;; Original Author: A.J. Rossini <rossini@u.washington.edu>
+;; Author: A.J. Rossini <rossini@u.washington.edu>
 ;; Created: 2001/02/06
-;; Maintainer: ESS Core Team <ESS-core@stat.math.ethz.ch>
+;; Maintainer: ESS Core Team <ESS-core@r-project.org>
 
-;; Keywords: start up, configuration.
+;; Keywords: languages
 
 ;; This file is part of ESS.
 
@@ -26,22 +26,21 @@
 ;; the Free Software Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.
 
 ;;; Commentary:
-;;; AJR copied S+5 to be S+6.
-;;; AJR copied S4 to be S+5.
-;;; DB contributed the changes from ess-sp3-d.el to
-;;; ess-s4-d.el. (removed the old ugly approach).
-;;; This file defines Sp5 customizations for ess-mode.  Lots of thanks
-;;; to RMH and JMC for code and suggestions
-;;; Thanks to MM for making this sensible.
 
-;;; Requires and Autoloads:
+;; AJR copied S+5 to be S+6.
+;; AJR copied S4 to be S+5.
+;; DB contributed the changes from ess-sp3-d.el to
+;; ess-s4-d.el. (removed the old ugly approach).
+;; This file defines Sp5 customizations for ess-mode.  Lots of thanks
+;; to RMH and JMC for code and suggestions
+;; Thanks to MM for making this sensible.
 
-(require 'ess-s-l)
+;;; Code:
 
 (autoload 'inferior-ess "ess-inf" "Run an ESS process.")
 (autoload 'ess-mode     "ess-mode" "Edit an ESS process.")
 
-;;; Code:
+(require 'ess-s-l)
 
 ;; You now need to make sure you've defined if you are running 5.0 or 5.1.
 ;; Lots of things are broken between them, GRR...
@@ -56,39 +55,37 @@
        (file-directory-p (concat directory ".Data/__Meta"))))
 
 (defvar S+6-directory-function
-  #'(lambda ()
-      (if (S+6-directory-p default-directory)
-	  default-directory
-	(or ess-directory default-directory))))
+  (lambda ()
+    (if (S+6-directory-p default-directory)
+        default-directory
+      (or ess-directory default-directory))))
 
 (defvar S+6-setup-directory-function
-  #'(lambda (startdir)
-      (if (and startdir (S+6-directory-p startdir))
-          (progn
-	    (setenv "S_WORK"
-		    (if (getenv "S_WORK")
-			(concat startdir ":" (getenv "S_WORK"))
-		      ;;(message "adding %s to S_WORK" startdir)
-		      startdir))
-            ))))
+  (lambda (startdir)
+    (when (and startdir (S+6-directory-p startdir))
+      (setenv "S_WORK"
+              (if (getenv "S_WORK")
+                  (concat startdir ":" (getenv "S_WORK"))
+                ;;(message "adding %s to S_WORK" startdir)
+                startdir)))))
 
 (defvar S+6-customize-alist
   (append
-   '((ess-local-customize-alist		. 'S+6-customize-alist)
-     (ess-dialect			. S+6-dialect-name)
-     (ess-loop-timeout			. ess-S-loop-timeout);fixme: dialect spec.
+   '((ess-local-customize-alist         . 'S+6-customize-alist)
+     (ess-dialect                       . S+6-dialect-name)
+     (ess-loop-timeout                  . ess-S-loop-timeout);fixme: dialect spec.
      (ess-function-pattern              . ess-R-function-pattern)
 
-     (ess-object-name-db-file		. "ess-sp6-namedb.el")
-     (inferior-ess-program		. inferior-S+6-program-name)
-     (inferior-ess-help-command	  . "help(\"%s\",pager=\"slynx -dump\",window=F)\n")
+     (ess-object-name-db-file           . "ess-sp6-namedb.el")
+     (inferior-ess-program              . inferior-S+6-program-name)
+     (inferior-ess-help-command   . "help(\"%s\",pager=\"slynx -dump\",window=F)\n")
      (inferior-ess-help-filetype . nil)
-     (inferior-ess-search-list-command	. "searchPaths()\n")
+     (inferior-ess-search-list-command  . "searchPaths()\n")
 
-     (ess-directory-function		. S+6-directory-function)
-     (ess-setup-directory-function	. S+6-setup-directory-function)
+     (ess-directory-function            . S+6-directory-function)
+     (ess-setup-directory-function      . S+6-setup-directory-function)
      (inferior-ess-start-args       . inferior-Splus-args)
-     (ess-STERM	 . "iESS")
+     (ess-STERM  . "iESS")
      )
    S+common-cust-alist)
 
@@ -143,7 +140,7 @@ If duplicate versions of the same program are found (which happens if
 the same path is listed on `exec-path' more than once), they are
 ignored by calling `ess-uniq-list'.
 Set this variable to nil to disable searching for other versions
-of S using this method.  
+of S using this method.
 If you set this variable, you need to restart Emacs (and set this variable
 before ess-site is loaded) for it to take effect.
 
@@ -162,16 +159,16 @@ ESS initialisation."
   ;; This works by creating a temp buffer where the template function is
   ;; edited so that X.Y is replaced by the version name
   (let ((template "")
-	(template-args)
-	(beg)
-	(versions)
-	(version)
-	(eval-buf (get-buffer-create "*ess-temp-s-evals*"))
-	(ess-s-versions-created)
+        (template-args)
+        (beg)
+        (versions)
+        (version)
+        (eval-buf (get-buffer-create "*ess-temp-s-evals*"))
+        (ess-s-versions-created)
 
-	(ess-s-versions-list ess-s-versions-list)
-	;; make local copy so it won't be destroyed globally
-	)
+        (ess-s-versions-list ess-s-versions-list)
+        ;; make local copy so it won't be destroyed globally
+        )
     ;;
     ;; This is the template function used for creating M-x Splus
     (setq template "(defun S-X.Y ()
@@ -188,35 +185,35 @@ This function was generated by `ess-s-versions-create'.\"
       (delete-region (point-min) (point-max))
 
       (when ess-s-versions
-	;; Find which versions of S we want.  Remove the pathname, leaving just
-	;; the name of the executable.
-	(setq versions
-	      (ess-uniq-list
-	       (mapcar 'file-name-nondirectory
-		       (apply 'nconc
-			      (mapcar 'ess-find-exec-completions
-				      ess-s-versions)))))
-	(ess-write-to-dribble-buffer
-	 (format "(S): ess-s-versions-create making M-x defuns for \n %s\n"
-		 (mapconcat 'identity versions "\n ")))
-	(setq ess-s-versions-created versions) ;keep copy for returning at end.
-	;; Iterate over each string in VERSIONS, creating a new defun each time.
-	(while versions
-	  (setq version (car versions)
-		versions (cdr versions))
-	  (setq beg (point))
-	  (insert template)
-	  (goto-char beg)
-	  (while (search-forward "S-X.Y" nil t)
-	    (replace-match version t t))
-	  (goto-char (point-max))
-	  ))
+        ;; Find which versions of S we want.  Remove the pathname, leaving just
+        ;; the name of the executable.
+        (setq versions
+              (ess-uniq-list
+               (mapcar 'file-name-nondirectory
+                       (apply 'nconc
+                              (mapcar 'ess-find-exec-completions
+                                      ess-s-versions)))))
+        (ess-write-to-dribble-buffer
+         (format "(S): ess-s-versions-create making M-x defuns for \n %s\n"
+                 (mapconcat 'identity versions "\n ")))
+        (setq ess-s-versions-created versions) ;keep copy for returning at end.
+        ;; Iterate over each string in VERSIONS, creating a new defun each time.
+        (while versions
+          (setq version (car versions)
+                versions (cdr versions))
+          (setq beg (point))
+          (insert template)
+          (goto-char beg)
+          (while (search-forward "S-X.Y" nil t)
+            (replace-match version t t))
+          (goto-char (point-max))
+          ))
 
       ;; Check if we have any static defuns to evaluate.
       (when ess-s-versions-list
 
-	;; Need a slightly different template for static defuns.
-	(setq template "(defun S-X.Y ()
+        ;; Need a slightly different template for static defuns.
+        (setq template "(defun S-X.Y ()
   \"Call S-X.Y, i.e., the S version 'S-X.Y' using ESS.
 This function will run S-FULL-PATH
 This function was generated by `ess-s-versions-create'.\"
@@ -225,8 +222,8 @@ This function was generated by `ess-s-versions-create'.\"
     (S+6)))
 
 ")
-	;; need another version of template, with args.
-	(setq template-args "(defun S-X.Y ()
+        ;; need another version of template, with args.
+        (setq template-args "(defun S-X.Y ()
   \"Call S-X.Y, i.e., the S version 'S-X.Y' using ESS.
 This function will run S-FULL-PATH
 This function was generated by `ess-s-versions-create'.\"
@@ -236,31 +233,31 @@ This function was generated by `ess-s-versions-create'.\"
     (S+6)))
 
 ")
-	(while ess-s-versions-list
-	  (let* ((this-S-version (car ess-s-versions-list))
-		 (S-defun (nth 0 this-S-version))
-		 (S-path  (nth 1 this-S-version))
-		 (S-args  (nth 2 this-S-version)))
-	    (setq ess-s-versions-list (cdr ess-s-versions-list))
-	  ;; Could do error checking here, that S-defun is not defined
-	  ;; before, and that S-path is valid.
-	  (setq beg (point))
-	  (insert
-	   (if S-args
-	       template-args
-	     template))
-	  (goto-char beg)
-	  (while (search-forward "S-X.Y" nil t)
-	    (replace-match S-defun t t))
-	  (goto-char beg)
-	  (while (search-forward "S-FULL-PATH" nil t)
-	    (replace-match S-path t t))
-	  (when S-args
-	    (goto-char beg)
-	    (while (search-forward "S-MYARGS" nil t)
-	      (replace-match S-args t t)))
-	  (goto-char (point-max))
-	  (add-to-list 'ess-s-versions-created S-defun 'append))))
+        (while ess-s-versions-list
+          (let* ((this-S-version (car ess-s-versions-list))
+                 (S-defun (nth 0 this-S-version))
+                 (S-path  (nth 1 this-S-version))
+                 (S-args  (nth 2 this-S-version)))
+            (setq ess-s-versions-list (cdr ess-s-versions-list))
+            ;; Could do error checking here, that S-defun is not defined
+            ;; before, and that S-path is valid.
+            (setq beg (point))
+            (insert
+             (if S-args
+                 template-args
+               template))
+            (goto-char beg)
+            (while (search-forward "S-X.Y" nil t)
+              (replace-match S-defun t t))
+            (goto-char beg)
+            (while (search-forward "S-FULL-PATH" nil t)
+              (replace-match S-path t t))
+            (when S-args
+              (goto-char beg)
+              (while (search-forward "S-MYARGS" nil t)
+                (replace-match S-args t t)))
+            (goto-char (point-max))
+            (add-to-list 'ess-s-versions-created S-defun 'append))))
 
       ;; buffer has now been created with defuns, so eval them!
       (eval-buffer)
