@@ -2,13 +2,13 @@
 
 ;; Copyright (C) 1997--1999 A. J. Rossini, Thomas Lumley
 ;; Copyright (C) 1997--2004 A.J. Rossini, Rich M. Heiberger, Martin
-;;	Maechler, Kurt Hornik, Rodney Sparapani, and Stephen Eglen.
+;;      Maechler, Kurt Hornik, Rodney Sparapani, and Stephen Eglen.
 
-;; Original Author: A.J. Rossini <rossini@biostat.washington.edu>
+;; Author: A.J. Rossini <rossini@biostat.washington.edu>
 ;; Created: 9 Sep 1998
-;; Maintainers: ESS-core <ESS-core@r-project.org>
+;; Maintainer: ESS-core <ESS-core@r-project.org>
 
-;; Keywords: start up, configuration.
+;; Keywords: languages
 
 ;; This file is part of ESS
 
@@ -26,18 +26,17 @@
 ;; along with GNU Emacs; see the file COPYING.  If not, write to
 ;; the Free Software Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.
 
-;;; Commentary: This file defines all the Stata customizations for
-;;; ess-mode.  It is somewhat based on Stata-mode by Thomas Lumley
-;;; <thomas@biostat.washington.edu>.
+;;; Commentary:
 
-;;; Requires and Autoloads:
+;; This file defines all the Stata customizations for ess-mode. It is somewhat
+;; based on Stata-mode by Thomas Lumley <thomas@biostat.washington.edu>.
 
-(require 'ess-sta-l)
+;;; Code:
 
 (autoload 'inferior-ess "ess-inf" "Run an ESS process.")
 (autoload 'ess-mode     "ess-mode" "Edit an ESS process.")
 
-; Code:
+(require 'ess-sta-l)
 
 (defvar STA-dialect-name "Stata"
   "Name of 'dialect' for Stata.");easily changeable in a user's .emacs
@@ -56,15 +55,19 @@
     (ess-object-name-db-file       . "ess-sta-namedb.el" )
     (inferior-ess-font-lock-keywords . ess-STA-mode-font-lock-keywords)
     (inferior-ess-program          . inferior-STA-program-name)
-    (inferior-ess-objects-command  . "description\n")
-    (inferior-ess-help-command     . "set more off\n help %s\n")
+    (inferior-ess-objects-command  . "describe\n")
+    (inferior-ess-help-command     . "help %s\n") ;; assumes set more off 
     (inferior-ess-exit-command     . "exit\n")
-    (inferior-ess-primary-prompt   . "^.") ;; "^. ?")
-    (inferior-ess-secondary-prompt . "^.") ;; "^. ?")
-    (comint-use-prompt-regexp-instead-of-fields . t) ;; emacs 21 and up
-    (inferior-ess-start-file       . nil) ;"~/.ess-stata")
-    (inferior-ess-start-args       . "")) ; "-q"
- "Variables to customize for Stata.")
+    ;; --more-- is necessary here (hangs otherwise if startup stata.msg is big)
+    (inferior-ess-primary-prompt   . "[.:] \\|--more--") 
+    (inferior-ess-secondary-prompt . "--more--")
+    (comint-use-prompt-regexp      . t)
+    (inferior-ess-start-file       . inferior-STA-start-file) ;"~/.ess-stata")
+    (inferior-ess-start-args       . inferior-STA-start-args)
+    (ess-get-help-topics-function  . 'ess-get-STA-help-topics)
+    (inferior-ess-search-list-command   . "set more off\n search()\n")
+    )
+  "Variables to customize for Stata.")
 
 
 (defun STA-mode (&optional proc-name)
@@ -82,15 +85,20 @@
   (setq ess-customize-alist STA-customize-alist)
   (ess-write-to-dribble-buffer
    (format "(STA): ess-dialect=%s , buf=%s \n"
-	   ess-dialect
-	   (current-buffer)))
-  (let ((sta-start-args
-	 (concat "TERM=emacs stata "
-	         inferior-ess-start-args
-		 (if start-args (read-string
-				 "Starting Args [possibly -k####] ? ")
-		   nil))))
-    (inferior-ess sta-start-args)))
+           ess-dialect
+           (current-buffer)))
+  (let ((sta-start-args 
+         (concat inferior-STA-start-args
+                 (when start-args (read-string "Starting Args [possibly -k####] ? ")))))
+    (inferior-ess sta-start-args)
+    (let ((proc (get-process ess-local-process-name)))
+      (while (process-get proc 'sec-prompt)
+        ;; get read of all --more-- if stata.msg is too long.
+        (ess-send-string proc "q")
+        (ess-wait-for-process proc t))
+      (ess-send-string proc "set more off")
+      (goto-char (point-max))
+      )))
 
 
 (defun STA-transcript-mode ()
@@ -98,7 +106,26 @@
   (interactive)
   (ess-transcript-mode STA-customize-alist))
 
+(defun ess--STA-retrive-topics-from-search ()
+  (with-current-buffer (ess-command inferior-ess-search-list-command)
+    (goto-char (point-min))
+    (let (topics)
+      (while (re-search-forward "(help \\(.+?\\)\\( if installed\\| for replacement.*\\)?)$" nil t)
+        (setq topics
+              (nconc (split-string (match-string-no-properties 1) ",\\|; +")
+                     topics)))
+      (nreverse (delete-dups topics))
+      )))
 
+(defun ess-get-STA-help-topics (&optional name)
+  "Return a list of current STA help topics associated with process NAME.
+If `ess-sp-change' is non-nil or `ess-help-topics-list' is nil, (re)-populate
+the latter and return it.  Otherwise, return `ess-help-topics-list'."
+  (or (ess-process-get 'help-topics)
+      (progn
+        (ess-process-put 'help-topics (ess--STA-retrive-topics-from-search))
+        (ess-process-get 'help-topics))
+      ))
 
  ; Provide package
 
