@@ -1,11 +1,13 @@
 ;;; ess-trns.el --- Support for manipulating S transcript files
 
 ;; Copyright (C) 1989--1994 Bates, Kademan, Ritter and Smith
-;; Copyright (C) 1997--2005 A.J. Rossini, Rich M. Heiberger, Martin
-;;	Maechler, Kurt Hornik, Rodney Sparapani, and Stephen Eglen.
+;; Copyright (C) 1997--2010 A.J. Rossini, Rich M. Heiberger, Martin
+;;      Maechler, Kurt Hornik, Rodney Sparapani, and Stephen Eglen.
+;; Copyright (C) 2011--2012 A.J. Rossini, Richard M. Heiberger, Martin Maechler,
+;;      Kurt Hornik, Rodney Sparapani, Stephen Eglen and Vitalie Spinu.
 
-;; Original Author: David Smith <dsmith@stats.adelaide.edu.au>
-;; Maintainers: ESS-core <ESS-core@stat.math.ethz.ch>
+;; Author: David Smith <dsmith@stats.adelaide.edu.au>
+;; Maintainer: ESS-core <ESS-core@r-project.org>
 
 ;; This file is part of ESS
 
@@ -16,11 +18,11 @@
 
 ;; This file is distributed in the hope that it will be useful,
 ;; but WITHOUT ANY WARRANTY; without even the implied warranty of
-;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.	 See the
+;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 ;; GNU General Public License for more details.
 
 ;; You should have received a copy of the GNU General Public License
-;; along with GNU Emacs; see the file COPYING.	If not, write to
+;; along with GNU Emacs; see the file COPYING.  If not, write to
 ;; the Free Software Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.
 
 ;;; Commentary:
@@ -37,24 +39,24 @@
   (require 'comint)
   (require 'ess-inf))
 
-(autoload 'ess-eval-region		"ess-inf" "[autoload]" t)
-(autoload 'ess-eval-region-and-go	"ess-inf" "[autoload]" t)
-(autoload 'ess-eval-function		"ess-inf" "[autoload]" t)
-(autoload 'ess-eval-function-and-go	"ess-inf" "[autoload]" t)
-(autoload 'ess-eval-line		"ess-inf" "[autoload]" t)
-(autoload 'ess-eval-line-and-go		"ess-inf" "[autoload]" t)
-(autoload 'ess-eval-line-and-step	"ess-inf" "[autoload]" t)
+(autoload 'ess-eval-region              "ess-inf" "[autoload]" t)
+(autoload 'ess-eval-region-and-go       "ess-inf" "[autoload]" t)
+(autoload 'ess-eval-function            "ess-inf" "[autoload]" t)
+(autoload 'ess-eval-function-and-go     "ess-inf" "[autoload]" t)
+(autoload 'ess-eval-line                "ess-inf" "[autoload]" t)
+(autoload 'ess-eval-line-and-go         "ess-inf" "[autoload]" t)
+(autoload 'ess-eval-line-and-step       "ess-inf" "[autoload]" t)
 
-(autoload 'comint-previous-prompt	"comint" "[autoload]" t)
-(autoload 'comint-next-prompt		"comint" "[autoload]" t)
+(autoload 'comint-previous-prompt       "comint" "[autoload]" t)
+(autoload 'comint-next-prompt           "comint" "[autoload]" t)
 
-(autoload 'ess-load-file		"ess-inf" "[autoload]" t)
-(autoload 'ess-request-a-process	"ess-inf" "(autoload)" nil)
-(autoload 'get-ess-buffer		"ess-inf" "(autoload)" nil)
-(autoload 'ess-switch-to-ESS		"ess-inf" "(autoload)" nil)
-(autoload 'ess-switch-to-end-of-ESS	"ess-inf" "(autoload)" nil)
-(autoload 'ess-eval-linewise		"ess-inf" "(autoload)" nil)
-(autoload 'inferior-ess-get-old-input	"ess-inf" "(autoload)" nil)
+(autoload 'ess-load-file                "ess-inf" "[autoload]" t)
+(autoload 'ess-request-a-process        "ess-inf" "(autoload)" nil)
+(autoload 'get-ess-buffer               "ess-inf" "(autoload)" nil)
+(autoload 'ess-switch-to-ESS            "ess-inf" "(autoload)" nil)
+(autoload 'ess-switch-to-end-of-ESS     "ess-inf" "(autoload)" nil)
+(autoload 'ess-eval-linewise            "ess-inf" "(autoload)" nil)
+(autoload 'inferior-ess-get-old-input   "ess-inf" "(autoload)" nil)
 
  ; ess-transcript-mode
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
@@ -66,94 +68,86 @@
 
 ;;*;; Major mode definition
 (defvar ess-transcript-mode-map nil "Keymap for `ess-transcript-mode'.")
-(if ess-transcript-mode-map
-    nil
-
-  (cond ((featurep 'xemacs)
-	 ;; Code for XEmacs
-	 (setq ess-transcript-mode-map (make-keymap))
-	 (set-keymap-parent ess-transcript-mode-map text-mode-map))
-	((not (featurep 'xemacs))
-	 ;; Code for GNU Emacs
-	 (setq ess-transcript-mode-map (make-sparse-keymap))))
+(unless ess-transcript-mode-map
+  (setq ess-transcript-mode-map (make-sparse-keymap))
 
   (define-key ess-transcript-mode-map "\C-c\C-s" 'ess-switch-process)
   (define-key ess-transcript-mode-map "\C-c\C-r" 'ess-eval-region)
   (define-key ess-transcript-mode-map "\C-c\M-r" 'ess-eval-region-and-go)
-;;  (define-key ess-transcript-mode-map "\M-\C-x"  'ess-eval-function)
-;;  (define-key ess-transcript-mode-map "\C-c\M-f" 'ess-eval-function-and-go)
-;;  (define-key ess-transcript-mode-map "\C-c\C-j" 'ess-eval-line)
-;;  (define-key ess-transcript-mode-map "\C-c\M-j" 'ess-eval-line-and-go)
+  ;;  (define-key ess-transcript-mode-map "\M-\C-x"  'ess-eval-function)
+  ;;  (define-key ess-transcript-mode-map "\C-c\M-f" 'ess-eval-function-and-go)
+  ;;  (define-key ess-transcript-mode-map "\C-c\C-j" 'ess-eval-line)
+  ;;  (define-key ess-transcript-mode-map "\C-c\M-j" 'ess-eval-line-and-go)
 
   (define-key ess-transcript-mode-map "\C-c\C-k"    'ess-force-buffer-current)
   (define-key ess-transcript-mode-map "\C-c\C-q"    'ess-quit)
 
   (define-key ess-transcript-mode-map "\C-c\C-j" 'ess-transcript-send-command)
   (define-key ess-transcript-mode-map "\C-c\M-j" 'ess-transcript-send-command-and-move)
-  (define-key ess-transcript-mode-map "\M-\C-a"	 'ess-beginning-of-function)
-  (define-key ess-transcript-mode-map "\M-\C-e"	 'ess-end-of-function)
+  (define-key ess-transcript-mode-map "\M-\C-a"  'ess-beginning-of-function)
+  (define-key ess-transcript-mode-map "\M-\C-e"  'ess-end-of-function)
   (define-key ess-transcript-mode-map "\C-c\C-y" 'ess-switch-to-ESS)
   (define-key ess-transcript-mode-map "\C-c\C-z" 'ess-switch-to-end-of-ESS)
   (define-key ess-transcript-mode-map "\C-c\C-v" 'ess-display-help-on-object)
   (define-key ess-transcript-mode-map "\C-c\C-d" 'ess-dump-object-into-edit-buffer)
   (define-key ess-transcript-mode-map "\C-c\C-t" 'ess-execute-in-tb)
-  (define-key ess-transcript-mode-map "\C-c\t"	 'ess-complete-object-name)
-  (define-key ess-transcript-mode-map "\C-a"	 'comint-bol)
-  (define-key ess-transcript-mode-map "\M-\t"	 'comint-replace-by-expanded-filename)
-  (define-key ess-transcript-mode-map "\M-?"	 'comint-dynamic-list-completions)
+  (define-key ess-transcript-mode-map "\C-c\t"   'ess-complete-object-name)
+  (define-key ess-transcript-mode-map "\C-a"     'comint-bol)
+  (define-key ess-transcript-mode-map "\M-\t"    'comint-replace-by-expanded-filename)
+  (define-key ess-transcript-mode-map "\M-?"     'comint-dynamic-list-completions)
   (define-key ess-transcript-mode-map "\C-c\C-k" 'ess-request-a-process)
-  (define-key ess-transcript-mode-map "{"	 'ess-electric-brace)
-  (define-key ess-transcript-mode-map "}"	 'ess-electric-brace)
-  (define-key ess-transcript-mode-map "\e\C-h"	 'ess-mark-function)
-  (define-key ess-transcript-mode-map "\e\C-q"	 'ess-indent-exp)
-  ;(define-key ess-transcript-mode-map "\177"	 'backward-delete-char-untabify)
-  (define-key ess-transcript-mode-map "\t"	 'ess-indent-command)
+  (define-key ess-transcript-mode-map "{"        'ess-electric-brace)
+  (define-key ess-transcript-mode-map "}"        'ess-electric-brace)
+  (define-key ess-transcript-mode-map "\e\C-h"   'ess-mark-function)
+  (define-key ess-transcript-mode-map "\e\C-q"   'ess-indent-exp)
+                                        ;(define-key ess-transcript-mode-map "\177"    'backward-delete-char-untabify)
+  (define-key ess-transcript-mode-map "\t"       'ess-indent-command)
 
   (define-key ess-transcript-mode-map "\C-c\C-p" 'comint-previous-prompt)
   (define-key ess-transcript-mode-map "\C-c\C-n" 'comint-next-prompt)
   ;; (define-key ess-transcript-mode-map "\C-c\C-n"    'ess-eval-line-and-step)
 
-  (define-key ess-transcript-mode-map "\r"	 'ess-transcript-send-command-and-move)
-  (define-key ess-transcript-mode-map "\M-\r"	 'ess-transcript-send-command)
-  (define-key ess-transcript-mode-map "\C-c\r"	 'ess-transcript-copy-command)
+  (define-key ess-transcript-mode-map "\r"       'ess-transcript-send-command-and-move)
+  (define-key ess-transcript-mode-map "\M-\r"    'ess-transcript-send-command)
+  (define-key ess-transcript-mode-map "\C-c\r"   'ess-transcript-copy-command)
   (define-key ess-transcript-mode-map "\C-c\C-w" 'ess-transcript-clean-region))
 
 (easy-menu-define
- ess-transcript-mode-menu ess-transcript-mode-map
- "Menu for use in S transcript mode."
- '("ESS-trans"
-   ["What is this? (beta)" ess-mouse-me			t]
-   ["Describe"	       describe-mode			t]
-   ["About"	      (ess-goto-info "Transcript Mode") t]
-   ["Send bug report"  ess-submit-bug-report		t]
-   "------"
-   ["Mark cmd group"   mark-paragraph		t]
-   ["Previous prompt"  comint-previous-prompt	t]
-   ["Next prompt"      comint-next-prompt	t]
-   "------"
-   ["Send and move" ess-transcript-send-command-and-move t]
-   ["Copy command"  ess-transcript-copy-command		t]
-   ["Send command"  ess-transcript-send-command		t]
-   ["Clean Region"  ess-transcript-DO-clean-region	t]
-   ["Switch S process" ess-switch-process		t]
-))
+  ess-transcript-mode-menu ess-transcript-mode-map
+  "Menu for use in S transcript mode."
+  '("ESS-trans"
+    ["What is this? (beta)" ess-mouse-me                        t]
+    ["Describe"         describe-mode                   t]
+    ["About"           (ess-goto-info "Transcript Mode") t]
+    ["Send bug report"  ess-submit-bug-report           t]
+    "------"
+    ["Mark cmd group"   mark-paragraph          t]
+    ["Previous prompt"  comint-previous-prompt  t]
+    ["Next prompt"      comint-next-prompt      t]
+    "------"
+    ["Send and move" ess-transcript-send-command-and-move t]
+    ["Copy command"  ess-transcript-copy-command                t]
+    ["Send command"  ess-transcript-send-command                t]
+    ["Clean Region"  ess-transcript-DO-clean-region     t]
+    ["Switch S process" ess-switch-process              t]
+    ))
 
 (unless (featurep 'xemacs)
   (if (featurep 'ess-trans)
       (define-key ess-transcript-mode-map [menu-bar ess-trans]
-	(cons "ess-trans" ess-transcript-mode-menu))
+        (cons "ess-trans" ess-transcript-mode-menu))
     (eval-after-load "ess-trans"
       '(define-key ess-transcript-mode-map
-	 [menu-bar ess-trans]
-	 (cons "ess-trans"
-	       ess-transcript-mode-menu)))))
+         [menu-bar ess-trans]
+         (cons "ess-trans"
+               ess-transcript-mode-menu)))))
 
 (when (featurep 'xemacs)
   (defun ess-transcript-mode-xemacs-menu ()
-  "Hook to install `ess-transcript-mode' menu for XEmacs (w/ easymenu)."
-  (if 'ess-transcript-mode
-	(easy-menu-add ess-transcript-mode-menu)
-    (easy-menu-remove ess-transcript-mode-menu)))
+    "Hook to install `ess-transcript-mode' menu for XEmacs (w/ easymenu)."
+    (if 'ess-transcript-mode
+        (easy-menu-add ess-transcript-mode-menu)
+      (easy-menu-remove ess-transcript-mode-menu)))
 
   (add-hook 'ess-transcript-mode-hook 'ess-transcript-mode-xemacs-menu))
 
@@ -180,27 +174,30 @@ in the region, leaving only the S commands.  Other keybindings are:
   (use-local-map ess-transcript-mode-map)
   (set-syntax-table ess-mode-syntax-table)
   (setq mode-line-process
-	'(" [" ess-local-process-name "]"))
+        '(" [" ess-local-process-name "]"))
   (make-local-variable 'ess-local-process-name)
   (setq ess-local-process-name nil)
+  (unless inferior-ess-prompt ;; For S languages it is set in custom-alist
+    (setq inferior-ess-prompt
+          ;; Do not anchor to bol with `^'
+          (concat "\\("
+                  inferior-ess-primary-prompt
+                  "\\|"
+                  inferior-ess-secondary-prompt
+                  "\\)")))
   (make-local-variable 'paragraph-start)
-  (setq paragraph-start (concat "^" inferior-ess-primary-prompt "\\|^\^L"))
+  (setq paragraph-start (concat "^" inferior-ess-prompt "\\|^\^L"))
   (make-local-variable 'paragraph-separate)
   (setq paragraph-separate "^\^L")
-  (setq inferior-ess-prompt
-	;; Do not anchor to bol with `^'       ; (copied from ess-inf.el)
-	(concat "\\("
-		inferior-ess-primary-prompt
-		"\\|"
-		inferior-ess-secondary-prompt
-		"\\)"))
+  (make-local-variable 'comint-use-prompt-regexp)
+  (setq comint-use-prompt-regexp t)
   (make-local-variable 'comint-prompt-regexp)
   (setq comint-prompt-regexp (concat "^" inferior-ess-prompt))
 
   ;; font-lock support
   (make-local-variable 'font-lock-defaults)
   (setq font-lock-defaults
-	'(inferior-ess-font-lock-keywords nil nil ((?' . "."))))
+        '(inferior-ess-font-lock-keywords nil nil ((?' . "."))))
 
   ;;; Keep <tabs> out of the code.
   (make-local-variable 'indent-tabs-mode)
@@ -216,34 +213,34 @@ The line should begin with a prompt.  The ESS process buffer is displayed if it
 is not already."
   (interactive)
   (let* ((proc (or ess-local-process-name
-		   (ess-request-a-process "Evaluate into which process? " t)))
-	 (ess-buf (get-ess-buffer proc)))
+                   (ess-request-a-process "Evaluate into which process? " t)))
+         (ess-buf (get-ess-buffer proc)))
     (setq ess-local-process-name proc)
     (if (get-buffer-window ess-buf) nil
       (display-buffer ess-buf t))
     (let ((input (inferior-ess-get-old-input)))
       (save-excursion
-	(set-buffer ess-buf)
-	(goto-char (point-max))
-	(ess-eval-linewise input)))))
+        (set-buffer ess-buf)
+        (goto-char (point-max))
+        (ess-eval-linewise input)))))
 
 (defun ess-transcript-send-command-and-move ()
   "Send the command on this line, and move point to the next command."
   (interactive)
-;; (ess-transcript-send-command) ;; This doesn't work properly
-;; replacement code begins
-   (let* ((proc (or ess-local-process-name
- 		   (ess-request-a-process "Evaluate into which process? " t)))
- 	 (ess-buf (get-ess-buffer proc)))
-     (setq ess-local-process-name proc)
-     (if (get-buffer-window ess-buf) nil
-       (display-buffer ess-buf t))
-     (let ((input (inferior-ess-get-old-input)))
-       (save-excursion
- 	(set-buffer ess-buf)
- 	(goto-char (point-max))
- 	(ess-eval-linewise input nil nil nil 1))))
-;; replacement code ends
+  ;; (ess-transcript-send-command) ;; This doesn't work properly
+  ;; replacement code begins
+  (let* ((proc (or ess-local-process-name
+                   (ess-request-a-process "Evaluate into which process? " t)))
+         (ess-buf (get-ess-buffer proc)))
+    (setq ess-local-process-name proc)
+    (if (get-buffer-window ess-buf) nil
+      (display-buffer ess-buf t))
+    (let ((input (inferior-ess-get-old-input)))
+      (save-excursion
+        (set-buffer ess-buf)
+        (goto-char (point-max))
+        (ess-eval-linewise input nil nil nil 1))))
+  ;; replacement code ends
   (goto-char ess-temp-point)
   (comint-next-prompt 1))
 
@@ -251,9 +248,9 @@ is not already."
   "Copy the command at point to the command line of the ESS process."
   (interactive)
   (let* ((proc (or ess-local-process-name
-		   (ess-request-a-process "Evaluate into which process? " t)))
-	 (ess-buf (process-buffer (get-process proc)))
-	 (input (inferior-ess-get-old-input)))
+                   (ess-request-a-process "Evaluate into which process? " t)))
+         (ess-buf (process-buffer (get-process proc)))
+         (input (inferior-ess-get-old-input)))
     (setq ess-local-process-name proc)
     (if (get-buffer-window ess-buf) nil
       (display-buffer ess-buf t))
@@ -272,22 +269,22 @@ prompt from those lines that remain.  Prefix argument means to use
   (unless inferior-ess-prompt
     (error "Cannot clean ESS transcript region in this mode!
  That only works in ess-transcript-mode or inferior-ess-mode ('*R*' etc)."
-	   ;; Maybe call ess-clean-region-in-new-transcript ?"))
-	   ))
+           ;; Maybe call ess-clean-region-in-new-transcript ?"))
+           ))
   (let ((do-toggle (and buffer-read-only even-if-read-only))
-	(ess-prompt-rx (concat "^" inferior-ess-prompt)))
+        (ess-prompt-rx (concat "^" inferior-ess-prompt)))
     (save-excursion
       (if do-toggle (toggle-read-only 0))
       (save-restriction
-	(unless (featurep 'xemacs) ;; does not exist in xemacs:
-	  (deactivate-mark))
-	(narrow-to-region beg end)
-	(goto-char (point-min))
-	(delete-non-matching-lines ess-prompt-rx)
-	(goto-char (point-min))
-	;; (replace-regexp  *  * ) :
-	(while (re-search-forward ess-prompt-rx nil t)
-	  (replace-match "" nil nil)))
+        (unless (featurep 'xemacs) ;; does not exist in xemacs:
+          (deactivate-mark))
+        (narrow-to-region beg end)
+        (goto-char (point-min))
+        (delete-non-matching-lines ess-prompt-rx)
+        (goto-char (point-min))
+        ;; (replace-regexp  *  * ) :
+        (while (re-search-forward ess-prompt-rx nil t)
+          (replace-match "" nil nil)))
 
       (if do-toggle (toggle-read-only 1)))))
 
@@ -302,12 +299,12 @@ prompt from those lines that remain.  Prefix argument means to use
 ;;   (let ((bname (buffer-file-name)))
 ;;     (setq bname (if bname .. ..))
 ;;     (let
-;; 	 (fbase (if fname (file-name-sans-extension (file-name-nondirectory fname))
-;; 		  (buffer-name)))
+;;       (fbase (if fname (file-name-sans-extension (file-name-nondirectory fname))
+;;                (buffer-name)))
 ;;
-;; 	 ;; the buffer name should be like a file name
-;; 	 (buf-nam ....)
-;; 	 (trns-buf (get-buffer-create fbase))
+;;       ;; the buffer name should be like a file name
+;;       (buf-nam ....)
+;;       (trns-buf (get-buffer-create fbase))
 ;;     (pop-to-buffer trns-buf)
 ;;     (ess-transcript-mode .....)
 ;; )))
@@ -330,11 +327,11 @@ Use point-min/max to obey narrow-to-region."
 
 ;;; This file is automatically placed in Outline minor mode.
 ;;; The file is structured as follows:
-;;; Chapters:	  ^L ;
-;;; Sections:	 ;;*;;
+;;; Chapters:     ^L ;
+;;; Sections:    ;;*;;
 ;;; Subsections: ;;;*;;;
-;;; Components:	 defuns, defvars, defconsts
-;;;		 Random code beginning with a ;;;;* comment
+;;; Components:  defuns, defvars, defconsts
+;;;              Random code beginning with a ;;;;* comment
 
 ;;; Local variables:
 ;;; mode: emacs-lisp
@@ -342,4 +339,4 @@ Use point-min/max to obey narrow-to-region."
 ;;; outline-regexp: "\^L\\|\\`;\\|;;\\*\\|;;;\\*\\|(def[cvu]\\|(setq\\|;;;;\\*"
 ;;; End:
 
-;;; ess-trans.el ends here
+;;; ess-trns.el ends here
